//=============================================================================
//	MuseScore - drop2+ plugin
//=============================================================================
import QtQuick 2.0
import MuseScore 3.0
MuseScore {
	description: "This plugin implements drop2"
	menuPath: "Plugins.drop2"
	version: "1.0"
	requiresScore: true

	function findchord(chordnames, count, tick) {
		for (var c = 0; c < count; c++){
			if (chordnames[c][1] == tick) {
				chordnames[c][0] = convertalt(chordnames[c][0])
				return chordnames[c][0];
			}
			else if((chordnames[c][1] > tick) && (c > 0)){
				//console.log("chordnames[c-1][0] = ", chordnames[c-1][0] + " " + chordnames[c-1][1])
				chordnames[c-1][0] = convertalt(chordnames[c-1][0])
				return chordnames[c-1][0];	
			}
		}
		return "";
	}

	function setCursorToTime(cursor, time) {
		cursor.rewind(0);
		while (cursor.segment) {
			var current_time = cursor.tick;
			if (current_time >= time) {
				return true;
			}
			cursor.next();
		}
		cursor.rewind(0);
		return false;
	} // end setcursor To Time

	// create and return a new Note element with given pitch, tpc
	function createNote(pitch, tpc) {
		var note = newElement(Element.NOTE);
		note.pitch = pitch;
		note.tpc = tpc;
		note.tpc1 = tpc;
		note.tpc2 = tpc;
		return note;
	} // end CreateNote

	//adds chord at current position. chord_notes is an array with pitch of notes.
	function addChord(cursor, chord_notes, duration) {
		for (var c = 0; c < chord_notes.length; c++) {
			//console.log("chord_notes = ", chord_notes[c]);
		}
		if (chord_notes.length == 0) return -1;
		var cur_time = cursor.tick;
		//console.log("cur_time =", cur_time)
		cursor.setDuration(duration, 1920);
		cursor.addNote(chord_notes[0]); //add 1st note
		var next_time = cursor.tick;
		setCursorToTime(cursor, cur_time); //rewind to this note
		var note = cursor.element.notes[0];
		note.tpc = chord_notes[3];
		var chord = cursor.element; //get the chord created when 1st note was inserted
		for (var i = 1; i < 3; i++) {
			var note = createNote(chord_notes[i], chord_notes[i + 3]);
			//console.log("note.pitch = ", note.pitch, "note.tpc = ", note.tpc);
			note.tpc = chord_notes[i + 3];
			chord.add(note); //add notes to the chord
			chord.notes[i].tpc = chord_notes[i + 3];
		}
		setCursorToTime(cursor, next_time);
		return 0;
	} //end AddChord

	function findDimChord(dimchord, chords) {
		for (var i = 0; i < chords.length; i++) {
			if (chords[i][0] == dimchord) return i;
		}
		return -1;
	}

	function enharmonic(str){
		var enharm = [
			["c#", "db"],
			["d#", "eb"],
			["e#", "f"],
			["f#", "gb"],
			["g#", "ab"],
			["a#", "bb"],
			["b#", "c"],
			["cb", "b"],
			["db", "c#"],
			["eb", "d#"],
			["fb", "e"],
			["gb", "f#"],
			["ab", "g#"],
			["bb", "a#"],
			["b", "cb"],
		];
	
		for (var i = 0; i < enharm.length; i++)	{
			if (str == enharm[i][0]){
				return enharm[i][1];
			}
		}
		return str;
	}
	// find the row in chords that matches thischord and this note or its enharmonic
	function onevoicing(chords, thischord, thisnote, enote, tpc2note){
		var i = 0;
		//find the first chords row matching chord
		while ((i < chords.length) && (chords[i][0] != thischord)) i++;
		
		while ((i < chords.length) && (chords[i][0] == thischord)) {
			// find thisnote match among the top notes of chords
			if (thisnote == tpc2note[chords[i][3][5] + 1][1] || enote == tpc2note[chords[i][3][5] + 1][1]) return i;
			i++;
		}
		return -1;
	}

	function bestVoicing(thisnote, thischord, chords, tpc2note) {
		//console.log ("thischord = ", thischord)
		//console.log ("thisnote = ", thisnote)
		if (thischord.length != 0 && thisnote != "rest") {
			var enote = enharmonic(thisnote);
			var trow = onevoicing(chords, thischord, thisnote, enote, tpc2note)
			if (trow != -1) return trow;

			// try the enharmonic chord if it has # or b
			var head = thischord.substr(0,2);
			//console.log ("head = ", head)
			if (head.substr(1,1) == "#"  || head.substr(1,1) == "b" ){
				//console.log (head)
				var oldhead = head;
				head = head.toString().toLowerCase();
				head = enharmonic(head);
				head = chordUCase(head);									
				
				//console.log ("oldchord = ", thischord)
				thischord = thischord.replace(oldhead, head);
				//console.log ("chord = ", thischord)
				var trow = onevoicing(chords, thischord, thisnote, enote, tpc2note)
				if (trow != -1) return trow;
			}
		}
		return -1;
	}

	function convertalt(alt) {
		var altconvert = [
			["Gb7alt", "C7"],
			["Db7alt", "G7"],
			["Ab7alt", "D7"],
			["Eb7alt", "A7"],
			["Bb7alt", "E7"],
			["F7alt", "B7"],
			["C7alt", "Gb7"],
			["G7alt", "Db7"],
			["D7alt", "Ab7"],
			["A7alt", "Eb7"],
			["E7alt", "Bb7"],
			["B7alt", "F7"],
			["F#7alt", "C7"],
			["C#7alt", "G7"],
			["G#7alt", "D7"],
			["D#7alt", "A7"],
			["A#7alt", "E7"],
		];
		//alt = chordUCase (alt);							
		for (var i = 0; i < altconvert.length; i++) {
			if (altconvert[i][0] == alt) {
				return altconvert[i][1];
			}
		}
		return alt;
	}

	function add1drop2(melnotes,c, chords, trow,cursor) {

		var offset = melnotes[c][1] - chords[trow][3][2];
		//console.log("melnotes[c][1] = ", melnotes[c][1])
		//console.log("chords[trow][3][2] = ", chords[trow][3][2])
		//console.log("offset = ", offset)
		
		var duration = melnotes[c + 1][2] - melnotes[c][2];
		var e = cursor.element;
		// with tuplettest2.mscz gives the following results:
		// e.tuplet.globalDuration.numerator =  1
		// e.tuplet.globalDuration.numerator =  2
		// e.tuplet.actualNotes =  5
		// e.tuplet.normalNotes =  4
		// globalDuration =  192
		//  198 Duration =  192
		//  200 Duration =  240 = 192 * 5/4

		if (e.tuplet) {
			//console.log ("in tuplet")
			console.log ("e.tuplet.globalDuration.numerator = ", e.tuplet.globalDuration.numerator)
			console.log ("e.tuplet.globalDuration.numerator = ", e.tuplet.globalDuration.denominator)
			console.log ("e.tuplet.actualNotes = ", e.tuplet.actualNotes)
			console.log ("e.tuplet.normalNotes = ", e.tuplet.normalNotes)
			var globalDuration = cursor.element.globalDuration.ticks;
            
            console.log ("globalDuration = ", globalDuration)
			console.log (" 198 Duration = ", duration)
			duration *= e.tuplet.actualNotes/e.tuplet.normalNotes;
			console.log (" 200 Duration = ", duration)
		}
		//console.log("duration = ", duration)
		// add the LH note
		cursor.staffIdx = 1;
		setCursorToTime(cursor, melnotes[c][2]);
		var cur_time = cursor.tick;
		cursor.setDuration(duration, 1920);
		cursor.addNote(chords[trow][1] + offset); //add 1st note
		var next_time = cursor.tick;
		setCursorToTime(cursor, cur_time); //rewind to this note
		var note = cursor.element.notes[0];
		note.tpc = chords[trow][2];
		//add the RH chord
		cursor.staffIdx = 0;
		var chord = chords[trow][3];
		var normchord = [];
		// adjust the pitches
		for (var j = 0; j < 3; j++) normchord.push(chords[trow][3][j] + offset);
		// copy the tpc
		for (var j = 3; j < 6; j++) normchord.push(chords[trow][3][j]);
		var cur_time = cursor.tick;
		addChord(cursor, normchord, duration);
	}

	function chordUCase(s){									
		var u = s.substr(0,1);								
		u = u.toUpperCase();								
		s = u + s.substr(1);								
		return s;								
	}

	onRun: {
		var tpc2note = [
			[-1, "fbb"],
			[0, "cbb"],
			[1, "gbb"],
			[2, "dbb"],
			[3, "abb"],
			[4, "ebb"],
			[5, "bbb"],
			[6, "fb"],
			[7, "cb"],
			[8, "gb"],
			[9, "db"],
			[10, "ab"],
			[11, "eb"],
			[12, "bb"],
			[13, "f"],
			[14, "c"],
			[15, "g"],
			[16, "d"],
			[17, "a"],
			[18, "e"],
			[19, "b"],
			[20, "f#"],
			[21, "c#"],
			[22, "g#"],
			[23, "d#"],
			[24, "a#"],
			[25, "e#"],
			[26, "b#"],
			[27, "f##"],
			[28, "c##"],
			[29, "g##"],
			[30, "d##"],
			[31, "a##"],
			[32, "e##"],
			[33, "b##"],
		];

		var cursor = curScore.newCursor()
		if (typeof curScore === 'undefined') {
			console.log("Please open a jazz lead sheet before calling execution of this function.");
			Qt.quit();
		}
		// chords[0]: name
		// chords[1]: pitch LH note
		// chords[2]: tpc LH note
		// chords[3]: pitches & tpc chord RH (3 each)
		var chords = [
			["adim", 54, 20, [60, 63, 69, 14, 11, 17]], //c,eb,a
			["a#dim", 55, 15, [61, 64, 70, 21, 18, 24]], //c#,e,a#
			["bbdim", 55, 15, [61, 64, 70, 21, 18, 12]], //c#,e,bb
			["bdim", 56, 10, [62, 65, 71, 16, 13, 19]], //d,f,b
			["cdim", 57, 17, [63, 66, 72, 11, 20, 14]], //eb,f#,c
			["c#dim", 58, 12, [64, 67, 73, 18, 15, 21]], //e,g,c#
			["dbdim", 58, 12, [64, 67, 73, 18, 15, 9]], //e,g,db
			["ddim", 59, 19, [65, 68, 74, 13, 10, 16]], //f,ab,d
			["d#dim", 60, 14, [66, 69, 75, 20, 17, 23]], //f#,a,d#
			["ebdim", 60, 14, [66, 69, 75, 20, 17, 11]], //f#,a,eb
			["edim", 61, 21, [67, 70, 76, 15, 12, 18]], //g,bb,e
			["fdim", 62, 16, [68, 71, 77, 10, 19, 13]], //ab,b,f
			["f#dim", 63, 11, [69, 72, 78, 17, 14, 20]], //a,c,f#
			["gbdim", 63, 11, [69, 72, 78, 17, 14, 8]], //a,c,gb
			["gdim", 64, 18, [70, 73, 79, 12, 21, 15]], //bb,c#,g
			["g#dim", 65, 13, [71, 74, 80, 19, 16, 22]], //b,d,g#
			["abdim", 65, 13, [71, 74, 80, 19, 16, 10]], //b,d,ab
        ["A",45,17,[52,54,63,18,20,11]], //a e f# eb
["A",49,21,[54,59,65,20,19,13]], //c# f# b f
["A",49,21,[56,57,64,22,17,18]], //g#,a,e
["A",52,18,[57,61,66,17,21,20]], //a,c#,f#
["A",52,18,[57,61,68,17,21,22]], //a,c#,g#
["A",54,20,[61,64,69,21,18,17]], //c#,e,a
["A",56,22,[61,64,69,21,18,17]], //c#,e,a
["A",57,17,[61,66,71,21,20,19]], //a c# f# b
["A",57,17,[64,66,73,18,20,21]], //e,f#,c#
["A",57,17,[64,68,73,18,22,21]], //e,g#,c#
["A",59,19,[65,69,74,13,17,16]], //a f b d
["A",61,21,[66,69,76,20,17,18]], //f#,a,e
["A#m7b5",52,18,[58,61,68,24,21,22]], //a#,c#,g#
["A#m7b5",52,18,[58,63,68,24,23,22]], //a#,d#,g#
["A#m7b5",56,22,[61,64,70,21,18,24]], //c#,e,a#
["A#m7b5",56,22,[63,64,70,23,18,24]], //d#,e,a#
["A#m7b5",58,24,[64,68,73,18,22,21]], //e,g#,c#
["A#m7b5",58,24,[64,68,75,18,22,23]], //e,g#,d#
["A#m7b5",61,21,[68,70,76,22,24,18]], //g#,a#,e
["A#m7b5",63,23,[68,70,76,22,24,18]], //g#,a#,e
["A6",49,21,[54,59,64,20,19,18]], //f# b c# e
["A6",54,20,[57,64,68,17,18,22]], //a f# e g#
["A6",54,20,[61,64,71,21,18,19]], //c# e f# b
["A7",43,15,[49,53,56,21,13,22]], //g c# f g#
["A7",45,17,[52,55,62,18,15,16]], //a e g d
["A7",49,21,[55,57,63,15,17,11]], //a c# g eb
["A7",49,21,[55,57,65,15,17,13]], //a g c# f
["A7",49,21,[55,57,65,15,17,13]], //g a c# f
["A7",57,17,[64,67,73,18,15,21]], //e,g,c#
["A7",57,17,[64,67,74,18,15,16]], //a e g d
["A7",59,19,[66,67,73,20,15,21]], //f#,g,c#
["A7",61,21,[67,69,76,15,17,18]], //g,a,e
["A7",61,21,[67,71,78,15,19,20]], //g,b,f#
["A7",64,18,[69,73,79,17,21,15]], //a,c#,g
["A7",66,20,[71,73,79,19,21,15]], //b,c#,g
["A7",67,15,[73,76,81,21,18,17]], //c#,e,a
["A7",67,15,[73,78,83,21,20,19]], //c#,f#,b
["A7#11",43,15,[49,51,58,21,11,12]], //g c# eb bb
["A7#11",51,11,[55,57,66,15,17,20]], //eb g a f#
["A7#11",51,11,[57,61,65,17,21,13]], //eb a c# f
["A7#11",55,15,[61,63,71,21,23,19]], //c#,d#,b
["A7#11",59,19,[63,67,73,23,15,21]], //d#,g,c#
["A7#11",61,21,[67,69,75,15,17,23]], //g,a,d#
["A7#11",61,21,[67,71,75,15,19,23]], //g,b,d#
["A7#11",63,23,[69,73,79,17,21,15]], //a,c#,g
["A7#11",63,23,[71,73,79,19,21,15]], //b,c#,g
["A7#11",67,15,[73,75,81,21,23,17]], //c#,d#,a
["A7#11",69,17,[75,79,85,23,15,21]], //d#,g,c#
["A7b13",55,15,[64,65,69,18,13,17]], //e,f,a
["A7b13",57,17,[65,67,76,13,15,18]], //f,g,e
["A7b13",59,19,[65,67,73,13,15,21]], //f,g,c#
["A7b13",61,21,[67,71,77,15,19,13]], //g,b,f
["A7b13",64,18,[67,69,77,15,17,13]], //g,a,f
["A7b13",65,13,[69,76,79,17,18,15]], //a,e,g
["A7b13",65,13,[71,73,79,19,21,15]], //b,c#,g
["A7b13",67,15,[73,77,83,21,13,19]], //c#,f,b
["A7b9",58,12,[66,67,73,20,15,21]], //f#,g,c#
["A7b9",61,21,[67,70,78,15,24,20]], //g,a#,f#
["A7b9",66,20,[70,73,79,24,21,15]], //a#,c#,g
["A7b9",67,15,[73,78,82,21,20,24]], //c#,f#,a#
["A7sus",45,17,[50,55,61,16,15,21]], //a d g c#
["A7sus",55,15,[62,64,69,16,18,17]], //d,e,a
["A7sus",55,15,[62,66,69,16,20,17]], //d,f#,a
["A7sus",57,17,[62,67,71,16,15,19]], //d,g,b
["A7sus",57,17,[64,67,74,18,15,16]], //e,g,d
["A7sus",57,17,[66,67,74,20,15,16]], //f#,g,d
["A7sus",59,19,[67,69,74,15,17,16]], //g,a,d
["A7sus",62,16,[67,69,76,15,17,18]], //g,a,e
["A7sus",62,16,[67,69,78,15,17,20]], //g,a,f#
["A7sus",62,16,[69,71,79,17,19,15]], //a,b,g
["A7sus",64,18,[69,74,79,17,16,15]], //a,d,g
["A7sus",66,20,[69,74,79,17,16,15]], //a,d,g
["A7sus",67,15,[71,74,81,19,16,17]], //b,d,a
["A7susb9",50,16,[57,58,64,17,12,18]], //d a bb e
["A7susb9",57,17,[62,67,70,16,15,12]], //d,g,bb
["A7susb9",58,24,[67,69,74,15,17,16]], //g,a,d
["A7susb9",62,16,[69,70,79,17,24,15]], //a,a#,g
["A7susb9",67,15,[70,74,81,24,16,17]], //a#,d,a
["Ab",44,10,[51,53,62,11,13,16]], //ab eb f d
["Ab",48,14,[53,58,64,13,12,18]], //c f bb e
["Ab",48,14,[55,56,63,15,10,11]], //g,ab,eb
["Ab",51,11,[56,60,65,10,14,13]], //ab,c,f
["Ab",51,11,[56,60,67,10,14,15]], //ab,c,g
["Ab",53,13,[60,63,68,14,11,10]], //c,eb,ab
["Ab",55,15,[60,63,68,14,11,10]], //c,eb,ab
["Ab",56,10,[60,65,70,14,13,12]], //ab c f bb
["Ab",56,10,[63,65,72,11,13,14]], //eb,f,c
["Ab",56,10,[63,67,72,11,15,14]], //eb,g,c
["Ab",58,12,[64,68,73,18,10,9]], //ab e bb db
["Ab",60,14,[65,68,75,13,10,11]], //f,ab,eb
["Ab6",48,14,[53,58,63,13,12,11]], //f bb c eb
["Ab6",53,13,[56,63,67,10,11,15]], //ab f eb g
["Ab6",53,13,[60,63,70,14,11,12]], //c eb f bb
["Ab7",42,8,[48,52,55,14,18,15]], //gb c e g
["Ab7",44,10,[51,54,61,11,8,9]], //ab eb gb db
["Ab7",48,14,[54,56,62,8,10,16]], //ab c gb d
["Ab7",48,14,[54,56,64,8,10,18]], //ab gb c e
["Ab7",48,14,[54,56,64,8,10,18]], //gb ab c e
["Ab7",56,10,[63,66,72,11,8,14]], //eb,gb,c
["Ab7",56,10,[63,66,73,11,20,9]], //ab eb f# db
["Ab7",58,12,[65,66,72,13,8,14]], //f,gb,c
["Ab7",60,14,[66,68,75,8,10,11]], //gb,ab,eb
["Ab7",60,14,[66,70,77,8,12,13]], //gb,bb,f
["Ab7",63,11,[68,72,78,10,14,8]], //ab,c,gb
["Ab7",65,13,[70,72,78,12,14,8]], //bb,c,gb
["Ab7",66,8,[72,75,80,14,11,10]], //c,eb,ab
["Ab7",66,8,[72,77,82,14,13,12]], //c,f,bb
["Ab7#11",42,8,[48,50,57,14,16,17]], //gb c d a
["Ab7#11",50,16,[54,56,65,8,10,13]], //d gb ab f
["Ab7#11",50,16,[56,60,64,10,14,18]], //d ab c e
["Ab7#11",54,8,[60,62,70,14,16,12]], //c,d,bb
["Ab7#11",58,12,[62,66,72,16,8,14]], //d,gb,c
["Ab7#11",60,14,[66,68,74,8,10,16]], //gb,ab,d
["Ab7#11",60,14,[66,70,74,8,12,16]], //gb,bb,d
["Ab7#11",62,16,[68,72,78,10,14,8]], //ab,c,gb
["Ab7#11",62,16,[70,72,78,12,14,8]], //bb,c,gb
["Ab7#11",66,8,[72,74,80,14,16,10]], //c,d,ab
["Ab7#11",68,10,[74,78,84,16,8,14]], //d,gb,c
["Ab7b13",54,8,[63,64,68,11,6,10]], //eb,fb,ab
["Ab7b13",56,10,[64,66,75,6,8,11]], //fb,gb,eb
["Ab7b13",58,12,[64,66,72,6,8,14]], //fb,gb,c
["Ab7b13",60,14,[66,70,76,8,12,6]], //gb,bb,fb
["Ab7b13",63,11,[66,68,76,8,10,6]], //gb,ab,fb
["Ab7b13",64,6,[68,75,78,10,11,8]], //ab,eb,gb
["Ab7b13",64,6,[70,72,78,12,14,8]], //bb,c,gb
["Ab7b13",66,8,[72,76,82,14,6,12]], //c,fb,bb
["Ab7b9",57,5,[65,66,72,13,8,14]], //f,gb,c
["Ab7b9",60,14,[66,69,77,8,17,13]], //gb,a,f
["Ab7b9",65,13,[69,72,78,17,14,8]], //a,c,gb
["Ab7b9",66,8,[72,77,81,14,13,17]], //c,f,a
["Ab7sus",44,10,[49,54,60,9,8,14]], //ab db gb c
["Ab7sus",54,8,[61,63,68,9,11,10]], //db,eb,ab
["Ab7sus",54,8,[61,65,68,9,13,10]], //db,f,ab
["Ab7sus",56,10,[61,66,70,9,8,12]], //db,gb,bb
["Ab7sus",56,10,[63,66,73,11,8,9]], //eb,gb,db
["Ab7sus",56,10,[65,66,73,13,8,9]], //f,gb,db
["Ab7sus",58,12,[66,68,73,8,10,9]], //gb,ab,db
["Ab7sus",61,9,[66,68,75,8,10,11]], //gb,ab,eb
["Ab7sus",61,9,[66,68,77,8,10,13]], //gb,ab,f
["Ab7sus",61,9,[68,70,78,10,12,8]], //ab,bb,gb
["Ab7sus",63,11,[68,73,78,10,9,8]], //ab,db,gb
["Ab7sus",65,13,[68,73,78,10,9,8]], //ab,db,gb
["Ab7sus",66,8,[70,73,80,12,9,10]], //bb,db,ab
["Ab7susb9",49,9,[56,57,63,10,17,11]], //db ab A eb
["Ab7susb9",56,10,[61,66,69,9,8,17]], //db,gb,a
["Ab7susb9",57,17,[66,68,73,8,10,9]], //gb,ab,db
["Ab7susb9",61,9,[68,69,78,10,17,8]], //ab,a,gb
["Ab7susb9",66,8,[69,73,80,17,9,10]], //a,db,ab
["Abm6",51,11,[56,59,65,10,19,13]], //eb ab b f
["Abm6",53,13,[56,63,71,10,11,19]], //ab eb f b
["Abm6",53,13,[59,63,68,19,11,10]], //f b eb ab
["Abm6",53,13,[59,63,68,19,11,10]], //f b eb ab
["Abm6",53,13,[59,63,69,19,11,17]], //b f eb a
["Abm6",53,13,[59,63,70,19,11,12]], //f b eb bb
["Abm6",59,19,[65,68,75,13,10,11]], //f b ab eb
["Abm7",47,19,[54,56,62,8,10,16]], //b gb ab d
["Abm7",51,11,[56,59,64,10,19,18]], //eb ab b e
["Abm7",51,11,[56,59,67,10,19,15]], //eb ab b g
["Abm7",54,8,[59,63,69,19,11,17]], //gb b eb A
["Abm7",59,7,[65,68,75,13,10,11]], //f,ab,eb
["Abm7",59,7,[66,68,73,8,10,9]], //gb,ab,db
["Abm7",59,7,[66,68,75,8,10,11]], //gb,ab,eb
["Abm7",61,9,[68,71,78,10,7,8]], //ab,cb,gb
["Abm7",63,11,[68,71,77,10,7,13]], //ab,cb,f
["Abm7",63,11,[68,71,78,10,7,8]], //ab,cb,gb
["Abm7",63,11,[70,71,78,12,7,8]], //bb,cb,gb
["Abm7",65,13,[71,75,80,7,11,10]], //cb,eb,ab
["Abm7",66,8,[71,73,80,7,9,10]], //cb,db,ab
["Abm7",66,8,[71,75,80,7,11,10]], //cb,eb,ab
["Abm7",66,8,[71,75,82,7,11,12]], //cb,eb,bb
["Abm7",68,10,[73,78,83,9,8,7]], //db,gb,cb
["Abm7",68,10,[75,77,83,11,13,7]], //eb,f,cb
["Abm7",68,10,[75,78,83,11,8,7]], //eb,gb,cb
["Abm7",70,12,[75,78,83,11,8,7]], //eb,gb,cb
["Abm7",71,7,[78,82,87,8,12,11]], //gb,bb,eb
["Abm7#5",44,10,[52,54,59,18,8,19]], //ab e gb b
["Abm7#5",54,8,[59,64,68,19,18,10]], //b gb e ab
["Abm7#5",56,10,[59,64,70,19,18,12]], //ab b e bb
["Abm7b5",50,16,[56,59,67,10,19,15]], //d ab b g
["Abm7b5",54,8,[59,62,69,19,16,17]], //d b gb A
["Abm7b5",56,10,[59,62,70,19,16,12]], //ab b d bb
["AbMaj#11",48,14,[51,55,62,11,15,16]], //c eb g d
["AbMaj#5",56,10,[60,64,70,14,18,12]], //ab c e bb
["AbMaj#5",56,10,[64,67,72,18,15,14]], //ab e g c
["AbMajb13",60,14,[64,68,75,18,10,11]], //ab c e eb
["AbmMaj7",51,11,[56,59,65,10,19,13]], //eb ab b f
["AbmMaj7",51,11,[56,59,67,10,7,15]], //ab,cb,g
["AbmMaj7",51,11,[58,59,67,12,7,15]], //bb,cb,g
["AbmMaj7",55,15,[59,63,68,7,11,10]], //cb,eb,ab
["AbmMaj7",55,15,[59,63,70,7,11,12]], //cb,eb,bb
["AbmMaj7",55,15,[59,63,73,19,11,9]], //b g eb db
["AbmMaj7",56,10,[63,67,71,11,15,7]], //eb,g,cb
["AbmMaj7",58,12,[63,67,71,11,15,7]], //eb,g,cb
["AbmMaj7",59,7,[67,68,75,15,10,11]], //g,ab,eb
["AbmMaj7",59,7,[67,70,75,15,12,11]], //g,bb,eb
["Am6",52,18,[57,60,66,17,14,20]], //e a c f#
["Am6",54,20,[57,64,72,17,18,14]], //a e f# c
["Am6",54,20,[60,64,69,14,18,17]], //f# c e a
["Am6",54,20,[60,64,69,14,18,17]], //f# c e a
["Am6",54,20,[60,64,70,14,18,12]], //c f# e bb
["Am6",54,20,[60,64,71,14,18,19]], //f# c e b
["Am6",60,14,[66,69,76,20,17,18]], //f# c a e
["Am7",48,14,[55,57,63,15,17,11]], //c g a eb
["Am7",52,18,[57,60,65,17,14,13]], //e a c f
["Am7",52,18,[57,60,68,17,14,10]], //e a c ab
["Am7",55,15,[60,64,70,14,18,12]], //g c e bb
["Am7",60,14,[66,69,76,20,17,18]], //f#,a,e
["Am7",60,14,[67,69,74,15,17,16]], //g,a,d
["Am7",60,14,[67,69,76,15,17,18]], //g,a,e
["Am7",62,16,[69,72,79,17,14,15]], //a,c,g
["Am7",64,18,[69,72,78,17,14,20]], //a,c,f#
["Am7",64,18,[69,72,79,17,14,15]], //a,c,g
["Am7",64,18,[71,72,79,19,14,15]], //b,c,g
["Am7",66,20,[72,76,81,14,18,17]], //c,e,a
["Am7",67,15,[72,74,81,14,16,17]], //c,d,a
["Am7",67,15,[72,76,81,14,18,17]], //c,e,a
["Am7",67,15,[72,76,83,14,18,19]], //c,e,b
["Am7",69,17,[74,79,84,16,15,14]], //d,g,c
["Am7",69,17,[76,78,84,18,20,14]], //e,f#,c
["Am7",69,17,[76,79,84,18,15,14]], //e,g,c
["Am7",71,19,[76,79,84,18,15,14]], //e,g,c
["Am7",72,14,[79,83,88,15,19,18]], //g,b,e
["Am7#5",45,17,[53,55,60,13,15,14]], //a f g c
["Am7#5",55,15,[60,65,69,14,13,17]], //c g f a
["Am7#5",57,17,[60,65,71,14,13,19]], //a c f b
["Am7b5",51,11,[57,60,67,17,14,15]], //a,c,g
["Am7b5",51,11,[57,60,68,17,14,10]], //eb a c ab
["Am7b5",51,11,[57,62,67,17,16,15]], //a,d,g
["Am7b5",55,15,[60,63,69,14,11,17]], //c,eb,a
["Am7b5",55,15,[60,63,70,14,11,12]], //eb c g bb
["Am7b5",55,15,[62,63,69,16,11,17]], //d,eb,a
["Am7b5",57,17,[60,63,71,14,11,19]], //a c eb b
["Am7b5",57,17,[63,67,72,11,15,14]], //eb,g,c
["Am7b5",57,17,[63,67,74,11,15,16]], //eb,g,d
["Am7b5",60,14,[67,69,75,15,17,11]], //g,a,eb
["Am7b5",62,16,[67,69,75,15,17,11]], //g,a,eb
["AMaj#11",49,21,[52,56,63,18,22,23]], //c# e g# d#
["AMaj#5",57,17,[61,65,71,21,13,19]], //a c# f b
["AMaj#5",57,17,[65,68,73,13,22,21]], //a f g# c#
["AMajb13",61,21,[65,69,76,13,17,18]], //a c# f e
["AmMaj7",52,18,[57,60,66,17,14,20]], //e a c f#
["AmMaj7",52,18,[57,60,68,17,14,22]], //a,c,g#
["AmMaj7",52,18,[59,60,68,19,14,22]], //b,c,g#
["AmMaj7",56,22,[60,64,69,14,18,17]], //c,e,a
["AmMaj7",56,22,[60,64,71,14,18,19]], //c,e,b
["AmMaj7",56,22,[60,64,74,14,18,16]], //c g# e d
["AmMaj7",57,17,[64,68,72,18,22,14]], //e,g#,c
["AmMaj7",59,19,[64,68,72,18,22,14]], //e,g#,c
["AmMaj7",60,14,[68,69,76,22,17,18]], //g#,a,e
["AmMaj7",60,14,[68,71,76,22,19,18]], //g#,b,e
["B",47,19,[54,56,65,20,22,13]], //b f# g# f
["B",51,11,[56,61,67,10,9,15]], //eb ab db g
["B",51,23,[58,59,66,24,19,20]], //a#,b,f#
["B",54,20,[59,63,68,19,23,22]], //b,d#,g#
["B",54,20,[59,63,70,19,23,24]], //b,d#,a#
["B",56,22,[63,66,71,23,20,19]], //d#,f#,b
["B",58,24,[63,66,71,23,20,19]], //d#,f#,b
["B",59,19,[63,68,73,11,10,9]], //b eb ab db
["B",59,19,[66,68,75,20,22,23]], //f#,g#,d#
["B",59,19,[66,70,75,20,24,23]], //f#,a#,d#
["B",61,9,[67,71,76,15,19,18]], //b g db e
["B",63,23,[68,71,78,22,19,20]], //g#,b,f#
["B6",51,11,[56,61,66,10,9,8]], //ab db eb gb
["B6",56,10,[59,66,70,19,8,12]], //b ab gb bb
["B6",56,10,[63,66,73,11,8,9]], //eb gb ab db
["B7",45,17,[51,55,58,23,15,24]], //a d# g a#
["B7",47,19,[54,57,64,20,17,18]], //b f# a e
["B7",51,11,[57,59,67,17,19,15]], //a b eb g
["B7",51,23,[57,59,65,17,19,13]], //b d# a f
["B7",51,23,[57,59,67,17,19,15]], //b a d# g
["B7",59,19,[66,69,75,20,17,23]], //f#,a,d#
["B7",59,19,[66,69,76,8,17,18]], //b gb a e
["B7",61,21,[68,69,75,22,17,23]], //g#,a,d#
["B7",63,23,[69,71,78,17,19,20]], //a,b,f#
["B7",63,23,[69,73,80,17,21,22]], //a,c#,g#
["B7",66,20,[71,75,81,19,23,17]], //b,d#,a
["B7",68,22,[73,75,81,21,23,17]], //c#,d#,a
["B7",69,17,[75,78,83,23,20,19]], //d#,f#,b
["B7",69,17,[75,80,85,23,22,21]], //d#,g#,c#
["B7#11",45,17,[51,53,60,23,13,14]], //a d# f c
["B7#11",53,13,[57,59,68,17,19,22]], //f a b g#
["B7#11",53,13,[59,63,67,19,23,15]], //f b d# g
["B7#11",57,17,[63,65,73,23,25,21]], //d#,e#,c#
["B7#11",61,21,[65,69,75,25,17,23]], //e#,a,d#
["B7#11",63,23,[69,71,77,17,19,25]], //a,b,e#
["B7#11",63,23,[69,73,77,17,21,25]], //a,c#,e#
["B7#11",65,25,[71,75,81,19,23,17]], //b,d#,a
["B7#11",65,25,[73,75,81,21,23,17]], //c#,d#,a
["B7#11",69,17,[75,77,83,23,25,19]], //d#,e#,b
["B7#11",71,19,[77,81,87,25,17,23]], //e#,a,d#
["B7b13",57,17,[66,67,71,20,15,19]], //f#,g,b
["B7b13",59,19,[67,69,78,15,17,20]], //g,a,f#
["B7b13",61,21,[67,69,75,15,17,23]], //g,a,d#
["B7b13",63,23,[69,73,79,17,21,15]], //a,c#,g
["B7b13",66,20,[69,71,79,17,19,15]], //a,b,g
["B7b13",67,15,[71,78,81,19,20,17]], //b,f#,a
["B7b13",67,15,[73,75,81,21,23,17]], //c#,d#,a
["B7b13",69,17,[75,79,85,23,15,21]], //d#,g,c#
["B7b9",60,14,[68,69,75,22,17,23]], //g#,a,d#
["B7b9",63,23,[69,72,80,17,26,22]], //a,b#,g#
["B7b9",68,22,[72,75,81,26,23,17]], //b#,d#,a
["B7b9",69,17,[75,80,84,23,22,26]], //d#,g#,b#
["B7sus",47,19,[52,57,63,18,17,23]], //b e a d#
["B7sus",57,17,[64,66,71,18,20,19]], //e,f#,b
["B7sus",57,17,[64,68,71,18,22,19]], //e,g#,b
["B7sus",59,19,[64,69,73,18,17,21]], //e,a,c#
["B7sus",59,19,[66,69,76,20,17,18]], //f#,a,e
["B7sus",59,19,[68,69,76,22,17,18]], //g#,a,e
["B7sus",61,21,[69,71,76,17,19,18]], //a,b,e
["B7sus",64,18,[69,71,78,17,19,20]], //a,b,f#
["B7sus",64,18,[69,71,80,17,19,22]], //a,b,g#
["B7sus",64,18,[71,73,81,19,21,17]], //b,c#,a
["B7sus",66,20,[71,76,81,19,18,17]], //b,e,a
["B7sus",68,22,[71,76,81,19,18,17]], //b,e,a
["B7sus",69,17,[73,76,83,21,18,19]], //c#,e,b
["B7susb9",52,18,[59,60,66,19,14,20]], //e b c f#
["B7susb9",59,19,[64,69,72,18,17,14]], //e,a,c
["B7susb9",60,26,[69,71,76,17,19,18]], //a,b,e
["B7susb9",64,18,[71,72,81,19,26,17]], //b,b#,a
["B7susb9",69,17,[72,76,83,26,18,19]], //b#,e,b
["Bb",46,12,[53,55,64,13,15,18]], //bb f g e
["Bb",50,16,[55,60,66,15,14,20]], //d g c f#
["Bb",50,16,[57,58,65,17,12,13]], //a,bb,f
["Bb",53,13,[58,62,67,12,16,15]], //bb,d,g
["Bb",53,13,[58,62,69,12,16,17]], //bb,d,a
["Bb",55,15,[62,65,70,16,13,12]], //d,f,bb
["Bb",57,17,[62,65,70,16,13,12]], //d,f,bb
["Bb",58,12,[62,67,72,16,15,14]], //bb d g c
["Bb",58,12,[65,67,74,13,15,16]], //f,g,d
["Bb",58,12,[65,69,74,13,17,16]], //f,a,d
["Bb",60,14,[66,70,75,8,12,11]], //bb gb c eb
["Bb",62,16,[67,70,77,15,12,13]], //g,bb,f
["Bb6",50,16,[55,60,65,15,14,13]], //g c d f
["Bb6",55,15,[58,65,69,12,13,17]], //bb g f a
["Bb6",55,15,[62,65,72,16,13,14]], //d f g c
["Bb7",44,10,[50,54,57,16,8,17]], //ab d gb a
["Bb7",46,12,[53,56,63,13,10,11]], //bb f ab eb
["Bb7",50,16,[56,58,64,10,12,18]], //bb d ab e
["Bb7",50,16,[56,58,66,10,12,20]], //ab bb d f#
["Bb7",50,16,[56,58,66,10,12,8]], //bb ab d gb
["Bb7",58,12,[65,68,74,13,10,16]], //f,ab,d
["Bb7",58,12,[65,68,75,13,22,11]], //bb f g# eb
["Bb7",60,14,[67,68,74,15,10,16]], //g,ab,d
["Bb7",62,16,[68,70,77,10,12,13]], //ab,bb,f
["Bb7",62,16,[68,72,79,10,14,15]], //ab,c,g
["Bb7",65,13,[70,74,80,12,16,10]], //bb,d,ab
["Bb7",67,15,[72,74,80,14,16,10]], //c,d,ab
["Bb7",68,10,[74,77,82,16,13,12]], //d,f,bb
["Bb7",68,10,[74,79,84,16,15,14]], //d,g,c
["Bb7#11",44,10,[50,52,59,16,18,19]], //ab d e b
["Bb7#11",52,18,[56,58,67,10,12,15]], //e ab bb g
["Bb7#11",52,18,[58,62,66,12,16,8]], //e bb d gb
["Bb7#11",56,10,[62,64,72,16,18,14]], //d,e,c
["Bb7#11",60,14,[64,68,74,18,10,16]], //e,ab,d
["Bb7#11",62,16,[68,70,76,10,12,18]], //ab,bb,e
["Bb7#11",62,16,[68,72,76,10,14,18]], //ab,c,e
["Bb7#11",64,18,[70,74,80,12,16,10]], //bb,d,ab
["Bb7#11",64,18,[72,74,80,14,16,10]], //c,d,ab
["Bb7#11",68,10,[74,76,82,16,18,12]], //d,e,bb
["Bb7#11",70,12,[76,80,86,18,10,16]], //e,ab,d
["Bb7b13",56,10,[65,66,70,13,8,12]], //f,gb,bb
["Bb7b13",58,12,[66,68,77,8,10,13]], //gb,ab,f
["Bb7b13",60,14,[66,68,74,8,10,16]], //gb,ab,d
["Bb7b13",62,16,[68,72,78,10,14,8]], //ab,c,gb
["Bb7b13",65,13,[68,70,78,10,12,8]], //ab,bb,gb
["Bb7b13",66,8,[70,77,80,12,13,10]], //bb,f,ab
["Bb7b13",66,8,[72,74,80,14,16,10]], //c,d,ab
["Bb7b13",68,10,[74,78,84,16,8,14]], //d,gb,c
["Bb7b9",59,7,[67,68,74,15,10,16]], //g,ab,d
["Bb7b9",62,16,[68,71,79,10,19,15]], //ab,b,g
["Bb7b9",67,15,[71,74,80,19,16,10]], //b,d,ab
["Bb7b9",68,10,[74,79,83,16,15,19]], //d,g,b
["Bb7sus",46,12,[51,56,62,11,10,16]], //bb eb ab d
["Bb7sus",56,10,[63,65,70,11,13,12]], //eb,f,bb
["Bb7sus",56,10,[63,67,70,11,15,12]], //eb,g,bb
["Bb7sus",58,12,[63,68,72,11,10,14]], //eb,ab,c
["Bb7sus",58,12,[65,68,75,13,10,11]], //f,ab,eb
["Bb7sus",58,12,[67,68,75,15,10,11]], //g,ab,eb
["Bb7sus",60,14,[68,70,75,10,12,11]], //ab,bb,eb
["Bb7sus",63,11,[68,70,77,10,12,13]], //ab,bb,f
["Bb7sus",63,11,[68,70,79,10,12,15]], //ab,bb,g
["Bb7sus",63,11,[70,72,80,12,14,10]], //bb,c,ab
["Bb7sus",65,13,[70,75,80,12,11,10]], //bb,eb,ab
["Bb7sus",67,15,[70,75,80,12,11,10]], //bb,eb,ab
["Bb7sus",68,10,[72,75,82,14,11,12]], //c,eb,bb
["Bb7susb9",51,11,[58,59,65,12,19,13]], //eb bb b f
["Bb7susb9",58,12,[63,68,71,11,10,7]], //eb,ab,cb
["Bb7susb9",59,19,[68,70,75,10,12,11]], //ab,bb,eb
["Bb7susb9",63,11,[70,71,80,12,19,10]], //bb,b,ab
["Bb7susb9",68,10,[71,75,82,19,11,12]], //b,eb,bb
["Bbm6",53,13,[58,61,67,12,9,15]], //f bb db g
["Bbm6",55,15,[58,65,73,12,13,9]], //bb f g db
["Bbm6",55,15,[61,65,70,9,13,12]], //g db f bb
["Bbm6",55,15,[61,65,70,9,13,12]], //g db f bb
["Bbm6",55,15,[61,65,71,9,13,19]], //db g f b
["Bbm6",55,15,[61,65,72,9,13,14]], //g db f c
["Bbm6",61,9,[67,70,77,15,12,13]], //g db bb f
["Bbm7",49,9,[55,58,65,15,12,13]], //g,bb,f
["Bbm7",49,9,[56,58,63,10,12,11]], //ab,bb,eb
["Bbm7",49,9,[56,58,64,10,12,18]], //db ab bb e
["Bbm7",49,9,[56,58,65,10,12,13]], //ab,bb,f
["Bbm7",51,11,[58,61,68,12,9,10]], //bb,db,ab
["Bbm7",53,13,[58,61,66,12,9,8]], //f bb db gb
["Bbm7",53,13,[58,61,67,12,9,15]], //bb,db,g
["Bbm7",53,13,[58,61,68,12,9,10]], //bb,db,ab
["Bbm7",53,13,[58,61,69,12,9,17]], //f bb db a
["Bbm7",53,13,[60,61,68,14,9,10]], //c,db,ab
["Bbm7",55,15,[61,65,70,9,13,12]], //db,f,bb
["Bbm7",56,10,[61,63,70,9,11,12]], //db,eb,bb
["Bbm7",56,10,[61,65,70,9,13,12]], //db,f,bb
["Bbm7",56,10,[61,65,71,9,13,19]], //ab db f b
["Bbm7",56,10,[61,65,72,9,13,14]], //db,f,c
["Bbm7",58,12,[63,68,73,11,10,9]], //eb,ab,db
["Bbm7",58,12,[65,67,73,13,15,9]], //f,g,db
["Bbm7",58,12,[65,68,73,13,10,9]], //f,ab,db
["Bbm7",60,14,[65,68,73,13,10,9]], //f,ab,db
["Bbm7",61,9,[68,72,77,10,14,13]], //ab,c,f
["Bbm7#5",46,12,[54,56,61,8,10,9]], //bb gb ab db
["Bbm7#5",56,10,[61,66,70,9,8,12]], //db ab gb bb
["Bbm7#5",58,12,[61,66,72,9,8,14]], //bb db gb c
["Bbm7b5",52,18,[58,61,69,12,9,17]], //e bb db a
["Bbm7b5",56,10,[61,64,71,9,18,19]], //e db ab b
["Bbm7b5",58,12,[61,64,72,9,18,14]], //bb db e c
["BbMaj#11",50,16,[53,57,64,13,17,18]], //d f a e
["BbMaj#5",58,12,[62,66,72,16,20,14]], //bb d f# c
["BbMaj#5",58,12,[66,69,74,20,17,16]], //bb f# a d
["BbMajb13",62,16,[66,70,77,8,12,13]], //bb d gb f
["BbmMaj7",53,13,[58,61,67,12,9,15]], //f bb db g
["BbmMaj7",53,13,[58,61,69,12,9,17]], //bb,db,a
["BbmMaj7",53,13,[60,61,69,14,9,17]], //c,db,a
["BbmMaj7",57,17,[61,65,70,9,13,12]], //db,f,bb
["BbmMaj7",57,17,[61,65,72,9,13,14]], //db,f,c
["BbmMaj7",57,17,[61,65,75,9,13,11]], //db a f eb
["BbmMaj7",58,12,[65,69,73,13,17,9]], //f,a,db
["BbmMaj7",60,14,[65,69,73,13,17,9]], //f,a,db
["BbmMaj7",61,9,[69,70,77,17,12,13]], //a,bb,f
["BbmMaj7",61,9,[69,72,77,17,14,13]], //a,c,f
["Bm6",54,20,[59,62,68,19,16,22]], //f# b d g#
["Bm6",56,10,[59,66,74,19,8,16]], //b gb ab d
["Bm6",56,10,[62,66,73,16,8,9]], //ab d gb db
["Bm6",56,22,[62,66,71,16,20,19]], //g# d f# b
["Bm6",56,22,[62,66,71,16,20,19]], //g# d f# b
["Bm6",56,22,[62,66,72,16,20,14]], //d g# f# c
["Bm6",62,16,[68,71,78,22,19,20]], //g# d b f#
["Bm7",50,16,[56,59,66,22,19,20]], //g#,b,f#
["Bm7",50,16,[57,59,64,17,19,18]], //a,b,e
["Bm7",50,16,[57,59,65,17,19,13]], //d a b f
["Bm7",50,16,[57,59,66,17,19,20]], //a,b,f#
["Bm7",52,18,[59,62,69,19,16,17]], //b,d,a
["Bm7",54,20,[59,62,67,19,16,15]], //f# b d g
["Bm7",54,20,[59,62,68,19,16,22]], //b,d,g#
["Bm7",54,20,[59,62,69,19,16,17]], //b,d,a
["Bm7",54,20,[59,62,70,19,16,12]], //f# b d bb
["Bm7",54,20,[61,62,69,21,16,17]], //c#,d,a
["Bm7",56,22,[62,66,71,16,20,19]], //d,f#,b
["Bm7",57,17,[62,64,71,16,18,19]], //d,e,b
["Bm7",57,17,[62,66,71,16,20,19]], //d,f#,b
["Bm7",57,17,[62,66,72,16,20,14]], //a d f# c
["Bm7",57,17,[62,66,73,16,20,21]], //d,f#,c#
["Bm7",59,19,[64,69,74,18,17,16]], //e,a,d
["Bm7",59,19,[66,68,74,20,22,16]], //f#,g#,d
["Bm7",59,19,[66,69,74,20,17,16]], //f#,a,d
["Bm7",61,21,[66,69,74,20,17,16]], //f#,a,d
["Bm7",62,16,[69,73,78,17,21,20]], //a,c#,f#
["Bm7#5",47,19,[55,57,62,15,17,16]], //b g a d
["Bm7#5",57,17,[62,67,71,16,15,19]], //d a g b
["Bm7#5",59,19,[62,67,73,16,15,21]], //b d g c#
["Bm7b5",53,13,[59,62,69,19,16,17]], //b,d,a
["Bm7b5",53,13,[59,62,70,19,16,12]], //f b d bb
["Bm7b5",53,13,[59,64,69,19,18,17]], //b,e,a
["Bm7b5",57,17,[62,65,71,16,13,19]], //d,f,b
["Bm7b5",57,17,[62,65,72,16,13,14]], //f d a c
["Bm7b5",57,17,[64,65,71,18,13,19]], //e,f,b
["Bm7b5",59,19,[62,65,73,16,13,21]], //b d f c#
["Bm7b5",59,19,[65,69,74,13,17,16]], //f,a,d
["Bm7b5",59,19,[65,69,76,13,17,18]], //f,a,e
["Bm7b5",62,16,[69,71,77,17,19,13]], //a,b,f
["Bm7b5",64,18,[69,71,77,17,19,13]], //a,b,f
["BMaj#11",51,11,[54,58,65,8,12,13]], //eb gb bb f
["BMaj#5",59,19,[63,67,73,11,15,9]], //b eb g db
["BMaj#5",59,19,[67,70,75,15,12,11]], //b g bb eb
["BMajb13",63,11,[67,71,78,15,19,8]], //b eb g gb
["BmMaj7",54,20,[59,62,70,19,16,24]], //b,d,a#
["BmMaj7",54,20,[61,62,70,21,16,24]], //c#,d,a#
["BmMaj7",54,8,[59,62,68,19,16,10]], //gb b d ab
["BmMaj7",58,12,[62,66,76,16,8,18]], //d bb gb e
["BmMaj7",58,24,[62,66,71,16,20,19]], //d,f#,b
["BmMaj7",58,24,[62,66,73,16,20,21]], //d,f#,c#
["BmMaj7",59,19,[66,70,74,20,24,16]], //f#,a#,d
["BmMaj7",61,21,[66,70,74,20,24,16]], //f#,a#,d
["BmMaj7",62,16,[70,71,78,24,19,20]], //a#,b,f#
["BmMaj7",62,16,[70,73,78,24,21,20]], //a#,c#,f#
["C",48,14,[55,57,66,15,17,20]], //c g a f#
["C",52,18,[57,62,68,17,16,22]], //e a d g#
["C",52,18,[59,60,67,19,14,15]], //b,c,g
["C",55,15,[60,64,69,14,18,17]], //c,e,a
["C",55,15,[60,64,71,14,18,19]], //c,e,b
["C",57,17,[64,67,72,18,15,14]], //e,g,c
["C",59,19,[64,67,72,18,15,14]], //e,g,c
["C",60,14,[64,69,74,18,17,16]], //c e a d
["C",60,14,[67,69,76,15,17,18]], //g,a,e
["C",60,14,[67,71,76,15,19,18]], //g,b,e
["C",62,16,[68,72,77,10,14,13]], //c ab d f
["C",64,18,[69,72,79,17,14,15]], //a,c,g
["C#m7",52,18,[58,61,68,24,21,22]], //a#,c#,g#
["C#m7",52,18,[59,61,66,19,21,20]], //b,c#,f#
["C#m7",52,18,[59,61,68,19,21,22]], //b,c#,g#
["C#m7",54,20,[61,64,71,21,18,19]], //c#,e,b
["C#m7",56,22,[61,64,70,21,18,24]], //c#,e,a#
["C#m7",56,22,[61,64,71,21,18,19]], //c#,e,b
["C#m7",56,22,[63,64,71,23,18,19]], //d#,e,b
["C#m7",58,24,[64,68,73,18,22,21]], //e,g#,c#
["C#m7",59,19,[64,66,73,18,20,21]], //e,f#,c#
["C#m7",59,19,[64,68,73,18,22,21]], //e,g#,c#
["C#m7",59,19,[64,68,75,18,22,23]], //e,g#,d#
["C#m7",61,21,[66,71,76,20,19,18]], //f#,b,e
["C#m7",61,21,[68,70,76,22,24,18]], //g#,a#,e
["C#m7",61,21,[68,71,76,22,19,18]], //g#,b,e
["C#m7",63,23,[68,71,76,22,19,18]], //g#,b,e
["C#m7",64,18,[71,75,80,19,23,22]], //b,d#,g#
["C#m7b5",55,15,[61,64,71,21,18,19]], //c#,e,b
["C#m7b5",55,15,[61,66,71,21,20,19]], //c#,f#,b
["C#m7b5",59,19,[64,67,73,18,15,21]], //e,g,c#
["C#m7b5",59,19,[66,67,73,20,15,21]], //f#,g,c#
["C#m7b5",61,21,[67,71,76,15,19,18]], //g,b,e
["C#m7b5",61,21,[67,71,78,15,19,20]], //g,b,f#
["C#m7b5",64,18,[71,73,79,19,21,15]], //b,c#,g
["C#m7b5",66,20,[71,73,79,19,21,15]], //b,c#,g
["C6",52,18,[57,62,67,17,16,15]], //a d e g
["C6",57,17,[60,67,71,14,15,19]], //c a g b
["C6",57,17,[64,67,74,18,15,16]], //e g a d
["C7",46,12,[52,56,59,18,10,19]], //bb e ab b
["C7",48,14,[55,58,65,15,12,13]], //c g bb f
["C7",52,18,[58,60,66,12,14,20]], //c e bb f#
["C7",52,18,[58,60,68,12,14,10]], //bb c e ab
["C7",52,18,[58,60,68,12,14,10]], //c bb e ab
["C7",60,14,[67,70,76,15,12,18]], //g,bb,e
["C7",60,14,[67,70,77,15,12,13]], //c g bb f
["C7",62,16,[69,70,76,17,12,18]], //a,bb,e
["C7",64,18,[70,72,79,12,14,15]], //bb,c,g
["C7",64,18,[70,74,81,12,16,17]], //bb,d,a
["C7",67,15,[72,76,82,14,18,12]], //c,e,bb
["C7",69,17,[74,76,82,16,18,12]], //d,e,bb
["C7",70,12,[76,79,84,18,15,14]], //e,g,c
["C7",70,12,[76,81,86,18,17,16]], //e,a,d
["C7#11",46,12,[52,54,61,18,8,21]], //bb e gb c#
["C7#11",54,20,[58,60,69,12,14,17]], //f# bb c a
["C7#11",54,20,[60,64,68,14,18,10]], //f# c e ab
["C7#11",58,12,[64,66,74,18,20,16]], //e,f#,d
["C7#11",62,16,[66,70,76,20,12,18]], //f#,bb,e
["C7#11",64,18,[70,72,78,12,14,20]], //bb,c,f#
["C7#11",64,18,[70,74,78,12,16,20]], //bb,d,f#
["C7#11",66,20,[72,76,82,14,18,12]], //c,e,bb
["C7#11",66,20,[74,76,82,16,18,12]], //d,e,bb
["C7#11",70,12,[76,78,84,18,20,14]], //e,f#,c
["C7#11",72,14,[78,82,88,20,12,18]], //f#,bb,e
["C7b13",58,12,[67,68,72,15,10,14]], //g,ab,c
["C7b13",60,14,[68,70,79,10,12,15]], //ab,bb,g
["C7b13",62,16,[68,70,76,10,12,18]], //ab,bb,e
["C7b13",64,18,[70,74,80,12,16,10]], //bb,d,ab
["C7b13",67,15,[70,72,80,12,14,10]], //bb,c,ab
["C7b13",68,10,[72,79,82,14,15,12]], //c,g,bb
["C7b13",68,10,[74,76,82,16,18,12]], //d,e,bb
["C7b13",70,12,[76,80,86,18,10,16]], //e,ab,d
["C7b9",61,9,[69,70,76,17,12,18]], //a,bb,e
["C7b9",64,18,[70,73,81,12,21,17]], //bb,c#,a
["C7b9",69,17,[73,76,82,21,18,12]], //c#,e,bb
["C7b9",70,12,[76,81,85,18,17,21]], //e,a,c#
["C7sus",48,14,[53,58,64,13,12,18]], //c f bb e
["C7sus",58,12,[65,67,72,13,15,14]], //f,g,c
["C7sus",58,12,[65,69,72,13,17,14]], //f,a,c
["C7sus",60,14,[65,70,74,13,12,16]], //f,bb,d
["C7sus",60,14,[67,70,77,15,12,13]], //g,bb,f
["C7sus",60,14,[69,70,77,17,12,13]], //a,bb,f
["C7sus",62,16,[70,72,77,12,14,13]], //bb,c,f
["C7sus",65,13,[70,72,79,12,14,15]], //bb,c,g
["C7sus",65,13,[70,72,81,12,14,17]], //bb,c,a
["C7sus",65,13,[72,74,82,14,16,12]], //c,d,bb
["C7sus",67,15,[72,77,82,14,13,12]], //c,f,bb
["C7sus",69,17,[72,77,82,14,13,12]], //c,f,bb
["C7sus",70,12,[74,77,84,16,13,14]], //d,f,c
["C7susb9",53,13,[60,61,67,14,9,15]], //f c db g
["C7susb9",60,14,[65,70,73,13,12,9]], //f,bb,db
["C7susb9",61,21,[70,72,77,12,14,13]], //bb,c,f
["C7susb9",65,13,[72,73,82,14,21,12]], //c,c#,bb
["C7susb9",70,12,[73,77,84,21,13,14]], //c#,f,c
["Cm6",55,15,[60,63,69,14,11,17]], //g c eb a
["Cm6",57,17,[60,67,75,14,15,11]], //c g a eb
["Cm6",57,17,[63,67,72,11,15,14]], //a eb g c
["Cm6",57,17,[63,67,72,11,15,14]], //a eb g c
["Cm6",57,17,[63,67,73,11,15,9]], //eb a g db
["Cm6",57,17,[63,67,74,11,15,16]], //a eb g d
["Cm6",63,11,[69,72,79,17,14,15]], //a eb c g
["Cm7",51,11,[57,60,67,17,14,15]], //a,c,g
["Cm7",51,11,[58,60,65,12,14,13]], //bb,c,f
["Cm7",51,11,[58,60,66,12,14,20]], //eb bb c f#
["Cm7",51,11,[58,60,67,12,14,15]], //bb,c,g
["Cm7",53,13,[60,63,70,14,11,12]], //c,eb,bb
["Cm7",55,15,[60,63,68,14,11,10]], //g c eb ab
["Cm7",55,15,[60,63,69,14,11,17]], //c,eb,a
["Cm7",55,15,[60,63,70,14,11,12]], //c,eb,bb
["Cm7",55,15,[60,63,71,14,11,19]], //g c eb b
["Cm7",55,15,[62,63,70,16,11,12]], //d,eb,bb
["Cm7",57,17,[63,67,72,11,15,14]], //eb,g,c
["Cm7",58,12,[63,65,72,11,13,14]], //eb,f,c
["Cm7",58,12,[63,67,72,11,15,14]], //eb,g,c
["Cm7",58,12,[63,67,73,11,15,9]], //bb eb g db
["Cm7",58,12,[63,67,74,11,15,16]], //eb,g,d
["Cm7",60,14,[65,70,75,13,12,11]], //f,bb,eb
["Cm7",60,14,[67,69,75,15,17,11]], //g,a,eb
["Cm7",60,14,[67,70,75,15,12,11]], //g,bb,eb
["Cm7",62,16,[67,70,75,15,12,11]], //g,bb,eb
["Cm7",63,11,[70,74,79,12,16,15]], //bb,d,g
["Cm7#5",48,14,[56,58,63,10,12,11]], //c ab bb eb
["Cm7#5",58,12,[63,68,72,11,10,14]], //eb bb ab c
["Cm7#5",60,14,[63,68,74,11,10,16]], //c eb ab d
["Cm7b5",54,8,[60,63,70,14,11,12]], //c,eb,bb
["Cm7b5",54,8,[60,63,71,14,11,19]], //gb c eb b
["Cm7b5",54,8,[60,65,70,14,13,12]], //c,f,bb
["Cm7b5",58,12,[63,66,72,11,8,14]], //eb,gb,c
["Cm7b5",58,12,[63,66,73,11,8,9]], //gb eb bb db
["Cm7b5",58,12,[65,66,72,13,8,14]], //f,gb,c
["Cm7b5",60,14,[63,66,74,11,8,16]], //c eb gb d
["Cm7b5",60,14,[66,70,75,8,12,11]], //gb,bb,eb
["Cm7b5",60,14,[66,70,77,8,12,13]], //gb,bb,f
["Cm7b5",63,11,[70,72,78,12,14,8]], //bb,c,gb
["Cm7b5",65,13,[70,72,78,12,14,8]], //bb,c,gb
["CMaj#11",52,18,[55,59,66,15,19,20]], //e g b f#
["CMaj#5",60,14,[64,68,74,18,22,16]], //c e g# d
["CMaj#5",60,14,[68,71,76,22,19,18]], //c g# b e
["CMajb13",64,18,[68,72,79,10,14,15]], //c e ab g
["CmMaj7",55,15,[60,63,69,14,11,17]], //g c eb a
["CmMaj7",55,15,[60,63,71,14,11,19]], //c,eb,b
["CmMaj7",55,15,[62,63,71,16,11,19]], //d,eb,b
["CmMaj7",59,19,[63,67,72,11,15,14]], //eb,g,c
["CmMaj7",59,19,[63,67,74,11,15,16]], //eb,g,d
["CmMaj7",59,19,[63,67,77,11,15,13]], //eb b g f
["CmMaj7",60,14,[67,71,75,15,19,11]], //g,b,eb
["CmMaj7",62,16,[67,71,75,15,19,11]], //g,b,eb
["CmMaj7",63,11,[71,72,79,19,14,15]], //b,c,g
["CmMaj7",63,11,[71,74,79,19,16,15]], //b,d,g
["D",42,20,[47,52,58,19,18,12]], //f# b e bb
["D",50,16,[54,59,64,20,19,18]], //d f# b e
["D",50,16,[57,59,68,17,19,10]], //d a b ab
["D",52,18,[58,62,67,12,16,15]], //d bb e g
["D",54,20,[61,62,69,21,16,17]], //c#,d,a
["D",57,17,[62,66,71,16,20,19]], //d,f#,b
["D",57,17,[62,66,73,16,20,21]], //d,f#,c#
["D",59,19,[66,69,74,20,17,16]], //f#,a,d
["D",61,21,[66,69,74,20,17,16]], //f#,a,d
["D",62,16,[69,71,78,17,19,20]], //a,b,f#
["D",62,16,[69,73,78,17,21,20]], //a,c#,f#
["D",66,20,[71,74,81,19,16,17]], //b,d,a
["D#m7b5",57,17,[63,66,73,23,20,21]], //d#,f#,c#
["D#m7b5",57,17,[63,68,73,23,22,21]], //d#,g#,c#
["D#m7b5",61,21,[66,69,75,20,17,23]], //f#,a,d#
["D#m7b5",61,21,[68,69,75,22,17,23]], //g#,a,d#
["D#m7b5",63,23,[69,73,78,17,21,20]], //a,c#,f#
["D#m7b5",63,23,[69,73,80,17,21,22]], //a,c#,g#
["D#m7b5",66,20,[73,75,81,21,23,17]], //c#,d#,a
["D#m7b5",68,22,[73,75,81,21,23,17]], //c#,d#,a
["D6",42,20,[47,52,57,19,18,17]], //b e f# a
["D6",47,19,[50,57,61,16,17,21]], //d b a c#
["D6",47,19,[54,57,64,20,17,18]], //f# a b e
["D7",42,20,[48,50,58,14,16,12]], //c d f# bb
["D7",48,14,[54,58,61,20,12,21]], //c f# bb c#
["D7",50,16,[57,60,67,17,14,15]], //d a c g
["D7",50,16,[57,60,67,17,14,15]], //d a c g
["D7",54,20,[60,62,68,14,16,10]], //d f# c ab
["D7",54,20,[60,62,70,14,16,12]], //d c f# bb
["D7",62,16,[69,72,78,17,14,20]], //a,c,f#
["D7",64,18,[71,72,78,19,14,20]], //b,c,f#
["D7",66,20,[72,74,81,14,16,17]], //c,d,a
["D7",66,20,[72,76,83,14,18,19]], //c,e,b
["D7",69,17,[74,78,84,16,20,14]], //d,f#,c
["D7",71,19,[76,78,84,18,20,14]], //e,f#,c
["D7",72,14,[78,81,86,20,17,16]], //f#,a,d
["D7",72,14,[78,83,88,20,19,18]], //f#,b,e
["D7#11",48,14,[54,56,63,20,10,11]], //c f# ab eb
["D7#11",56,10,[60,62,71,14,16,19]], //ab c d b
["D7#11",56,10,[62,66,70,16,20,12]], //ab d f# bb
["D7#11",60,14,[66,68,76,20,22,18]], //f#,g#,e
["D7#11",64,18,[68,72,78,22,14,20]], //g#,c,f#
["D7#11",66,20,[72,74,80,14,16,22]], //c,d,g#
["D7#11",66,20,[72,76,80,14,18,22]], //c,e,g#
["D7#11",68,22,[74,78,84,16,20,14]], //d,f#,c
["D7#11",68,22,[76,78,84,18,20,14]], //e,f#,c
["D7#11",72,14,[78,80,86,20,22,16]], //f#,g#,d
["D7#11",74,16,[80,84,90,22,14,20]], //g#,c,f#
["D7b13",60,14,[69,70,74,17,12,16]], //a,bb,d
["D7b13",62,16,[70,72,81,12,14,17]], //bb,c,a
["D7b13",64,18,[70,72,78,12,14,20]], //bb,c,f#
["D7b13",66,20,[72,76,82,14,18,12]], //c,e,bb
["D7b13",69,17,[72,74,82,14,16,12]], //c,d,bb
["D7b13",70,12,[74,81,84,16,17,14]], //d,a,c
["D7b13",70,12,[76,78,84,18,20,14]], //e,f#,c
["D7b13",72,14,[78,82,88,20,12,18]], //f#,bb,e
["D7b9",63,11,[71,72,78,19,14,20]], //b,c,f#
["D7b9",66,20,[72,75,83,14,23,19]], //c,d#,b
["D7b9",71,19,[75,78,84,23,20,14]], //d#,f#,c
["D7b9",72,14,[78,83,87,20,19,23]], //f#,b,d#
["D7sus",50,16,[55,60,66,15,14,20]], //d g c f#
["D7sus",60,14,[67,69,74,15,17,16]], //g,a,d
["D7sus",60,14,[67,71,74,15,19,16]], //g,b,d
["D7sus",62,16,[67,72,76,15,14,18]], //g,c,e
["D7sus",62,16,[69,72,79,17,14,15]], //a,c,g
["D7sus",62,16,[71,72,79,19,14,15]], //b,c,g
["D7sus",64,18,[72,74,79,14,16,15]], //c,d,g
["D7sus",67,15,[72,74,81,14,16,17]], //c,d,a
["D7sus",67,15,[72,74,83,14,16,19]], //c,d,b
["D7sus",67,15,[74,76,84,16,18,14]], //d,e,c
["D7sus",69,17,[74,79,84,16,15,14]], //d,g,c
["D7sus",71,19,[74,79,84,16,15,14]], //d,g,c
["D7sus",72,14,[76,79,86,18,15,16]], //e,g,d
["D7susb9",55,15,[62,63,69,16,11,17]], //g d eb a
["D7susb9",62,16,[67,72,75,15,14,11]], //g,c,eb
["D7susb9",63,23,[72,74,79,14,16,15]], //c,d,g
["D7susb9",67,15,[74,75,84,16,23,14]], //d,d#,c
["D7susb9",72,14,[75,79,86,23,15,16]], //d#,g,d
["Db",41,13,[46,51,57,12,11,17]], //f bb eb a
["Db",49,9,[53,58,63,13,12,11]], //db f bb eb
["Db",49,9,[56,58,67,10,12,15]], //db ab bb g
["Db",51,11,[57,61,66,17,9,8]], //db a eb gb
["Db",53,13,[60,61,68,14,9,10]], //c,db,ab
["Db",56,10,[61,65,70,9,13,12]], //db,f,bb
["Db",56,10,[61,65,72,9,13,14]], //db,f,c
["Db",58,12,[65,68,73,13,10,9]], //f,ab,db
["Db",60,14,[65,68,73,13,10,9]], //f,ab,db
["Db",61,9,[68,70,77,10,12,13]], //ab,bb,f
["Db",61,9,[68,72,77,10,14,13]], //ab,c,f
["Db",65,13,[70,73,80,12,9,10]], //bb,db,ab
["Db6",41,13,[46,51,56,12,11,10]], //bb eb f ab
["Db6",46,12,[49,56,60,9,10,14]], //db bb ab c
["Db6",46,12,[53,56,63,13,10,11]], //f ab bb eb
["Db7",41,13,[47,49,57,19,9,17]], //b db f a
["Db7",47,19,[53,57,60,13,17,14]], //b f A c
["Db7",49,9,[56,59,66,10,19,8]], //db ab b gb
["Db7",53,13,[59,61,67,19,9,15]], //db f b g
["Db7",53,13,[59,61,69,19,9,17]], //db b f A
["Db7",61,9,[68,71,77,10,7,13]], //ab,cb,f
["Db7",61,9,[68,71,78,10,19,8]], //db ab b gb
["Db7",63,11,[70,71,77,12,7,13]], //bb,cb,f
["Db7",65,13,[71,73,80,7,9,10]], //cb,db,ab
["Db7",65,13,[71,75,82,7,11,12]], //cb,eb,bb
["Db7",68,10,[73,77,83,9,13,7]], //db,f,cb
["Db7",70,12,[75,77,83,11,13,7]], //eb,f,cb
["Db7",71,7,[77,80,85,13,10,9]], //f,ab,db
["Db7",71,7,[77,82,87,13,12,11]], //f,bb,eb
["Db7#11",47,19,[53,55,62,13,15,16]], //b f g d
["Db7#11",55,15,[59,61,70,19,9,12]], //g b db bb
["Db7#11",55,15,[61,65,69,9,13,17]], //g db f a
["Db7#11",59,7,[65,67,75,13,15,11]], //f,g,eb
["Db7#11",63,11,[67,71,77,15,7,13]], //g,cb,f
["Db7#11",65,13,[71,73,79,7,9,15]], //cb,db,g
["Db7#11",65,13,[71,75,79,7,11,15]], //cb,eb,g
["Db7#11",67,15,[73,77,83,9,13,7]], //db,f,cb
["Db7#11",67,15,[75,77,83,11,13,7]], //eb,f,cb
["Db7#11",71,7,[77,79,85,13,15,9]], //f,g,db
["Db7#11",73,9,[79,83,89,15,7,13]], //g,cb,f
["Db7b13",59,7,[68,69,73,10,17,9]], //ab,a,db
["Db7b13",61,9,[69,71,80,17,7,10]], //a,cb,ab
["Db7b13",63,11,[69,71,77,17,7,13]], //a,cb,f
["Db7b13",65,13,[71,75,81,7,11,17]], //cb,eb,a
["Db7b13",68,10,[71,73,81,7,9,17]], //cb,db,a
["Db7b13",69,17,[73,80,83,9,10,7]], //db,ab,cb
["Db7b13",69,17,[75,77,83,11,13,7]], //eb,f,cb
["Db7b13",71,7,[77,81,87,13,17,11]], //f,a,eb
["Db7b9",62,4,[70,71,77,12,7,13]], //bb,cb,f
["Db7b9",65,13,[71,74,82,7,16,12]], //cb,d,bb
["Db7b9",70,12,[74,77,83,16,13,7]], //d,f,cb
["Db7b9",71,7,[77,82,86,13,12,16]], //f,bb,d
["Db7sus",49,9,[54,59,65,8,19,13]], //db gb b f
["Db7sus",59,7,[66,68,73,8,10,9]], //gb,ab,db
["Db7sus",59,7,[66,70,73,8,12,9]], //gb,bb,db
["Db7sus",61,9,[66,71,75,8,7,11]], //gb,cb,eb
["Db7sus",61,9,[68,71,78,10,7,8]], //ab,cb,gb
["Db7sus",61,9,[70,71,78,12,7,8]], //bb,cb,gb
["Db7sus",63,11,[71,73,78,7,9,8]], //cb,db,gb
["Db7sus",66,8,[71,73,80,7,9,10]], //cb,db,ab
["Db7sus",66,8,[71,73,82,7,9,12]], //cb,db,bb
["Db7sus",66,8,[73,75,83,9,11,7]], //db,eb,cb
["Db7sus",68,10,[73,78,83,9,8,7]], //db,gb,cb
["Db7sus",70,12,[73,78,83,9,8,7]], //db,gb,cb
["Db7sus",71,7,[75,78,85,11,8,9]], //eb,gb,db
["Db7susb9",54,8,[61,62,68,9,16,10]], //gb db d ab
["Db7susb9",61,9,[66,71,74,8,7,16]], //gb,cb,d
["Db7susb9",62,16,[71,73,78,7,9,8]], //cb,db,gb
["Db7susb9",66,8,[73,74,83,9,16,7]], //db,d,cb
["Db7susb9",71,7,[74,78,85,16,8,9]], //d,gb,db
["Dbm6",46,12,[49,56,64,9,10,18]], //db ab bb e
["Dbm6",46,12,[52,56,63,18,10,11]], //bb e ab eb
["Dbm6",56,10,[61,64,70,9,18,12]], //ab db e bb
["Dbm6",58,12,[64,68,73,18,10,9]], //bb e ab db
["Dbm6",58,12,[64,68,73,18,10,9]], //bb e ab db
["Dbm6",58,12,[64,68,74,18,10,16]], //e bb ab d
["Dbm6",64,18,[70,73,80,12,9,10]], //bb e db ab
["Dbm7",52,18,[59,61,67,19,9,15]], //e b db g
["Dbm7",56,10,[61,64,69,9,18,17]], //ab db e a
["Dbm7",56,10,[61,64,72,9,18,14]], //ab db e c
["Dbm7",59,19,[64,68,74,18,10,16]], //b e ab d
["Dbm7#5",49,9,[57,59,64,17,19,18]], //db a b e
["Dbm7#5",59,19,[64,69,73,18,17,9]], //e b a db
["Dbm7#5",61,9,[64,69,75,18,17,11]], //db e a eb
["Dbm7b5",55,15,[61,64,72,9,18,14]], //g db e c
["Dbm7b5",59,19,[64,67,74,18,15,16]], //g e b d
["Dbm7b5",61,9,[64,67,75,18,15,11]], //db e g eb
["DbMaj#11",41,13,[44,48,55,10,14,15]], //f ab c g
["DbMaj#5",49,9,[53,57,63,13,17,11]], //db f a eb
["DbMaj#5",49,9,[57,60,65,17,14,13]], //db a c f
["DbMajb13",53,13,[57,61,68,17,9,10]], //db f A ab
["DbmMaj7",44,10,[49,52,58,9,18,12]], //ab db e bb
["DbmMaj7",48,14,[52,56,66,18,10,8]], //e c ab gb
["DbmMaj7",56,10,[61,64,72,9,6,14]], //db,fb,c
["DbmMaj7",56,10,[63,64,72,11,6,14]], //eb,fb,c
["DbmMaj7",60,14,[64,68,73,6,10,9]], //fb,ab,db
["DbmMaj7",60,14,[64,68,75,6,10,11]], //fb,ab,eb
["DbmMaj7",61,9,[68,72,76,10,14,6]], //ab,c,fb
["DbmMaj7",63,11,[68,72,76,10,14,6]], //ab,c,fb
["DbmMaj7",64,6,[72,73,80,14,9,10]], //c,db,ab
["DbmMaj7",64,6,[72,75,80,14,11,10]], //c,eb,ab
["Dm6",47,19,[50,57,65,16,17,13]], //d a b f
["Dm6",47,19,[53,57,64,13,17,18]], //b f a e
["Dm6",57,17,[62,65,71,16,13,19]], //a d f b
["Dm6",59,19,[65,69,74,13,17,16]], //b f a d
["Dm6",59,19,[65,69,74,13,17,16]], //b f a d
["Dm6",59,19,[65,69,75,13,17,11]], //f b a eb
["Dm6",65,13,[71,74,81,19,16,17]], //b f d a
["Dm7",53,13,[59,62,69,19,16,17]], //b,d,a
["Dm7",53,13,[60,62,67,14,16,15]], //c,d,g
["Dm7",53,13,[60,62,68,14,16,10]], //f c d ab
["Dm7",53,13,[60,62,69,14,16,17]], //c,d,a
["Dm7",55,15,[62,65,72,16,13,14]], //d,f,c
["Dm7",57,17,[62,65,70,16,13,12]], //a d f bb
["Dm7",57,17,[62,65,71,16,13,19]], //d,f,b
["Dm7",57,17,[62,65,72,16,13,14]], //d,f,c
["Dm7",57,17,[62,65,73,16,13,21]], //a d f c#
["Dm7",57,17,[64,65,72,18,13,14]], //e,f,c
["Dm7",59,19,[65,69,74,13,17,16]], //f,a,d
["Dm7",60,14,[65,67,74,13,15,16]], //f,g,d
["Dm7",60,14,[65,69,74,13,17,16]], //f,a,d
["Dm7",60,14,[65,69,75,13,17,11]], //c f a eb
["Dm7",60,14,[65,69,76,13,17,18]], //f,a,e
["Dm7",62,16,[67,72,77,15,14,13]], //g,c,f
["Dm7",62,16,[69,71,77,17,19,13]], //a,b,f
["Dm7",62,16,[69,72,77,17,14,13]], //a,c,f
["Dm7",64,18,[69,72,77,17,14,13]], //a,c,f
["Dm7",65,13,[72,76,81,14,18,17]], //c,e,a
["Dm7#5",50,16,[58,60,65,12,14,13]], //d bb c f
["Dm7#5",60,14,[65,70,74,13,12,16]], //f c bb d
["Dm7#5",62,16,[65,70,76,13,12,18]], //d f bb e
["Dm7b5",56,10,[62,65,72,16,13,14]], //d,f,c
["Dm7b5",56,10,[62,65,73,16,13,21]], //ab d f c#
["Dm7b5",56,10,[62,67,72,16,15,14]], //d,g,c
["Dm7b5",60,14,[65,68,74,13,10,16]], //f,ab,d
["Dm7b5",60,14,[65,68,75,13,10,11]], //ab f c eb
["Dm7b5",60,14,[67,68,74,15,10,16]], //g,ab,d
["Dm7b5",62,16,[65,68,76,13,10,18]], //d f ab e
["Dm7b5",62,16,[68,72,77,10,14,13]], //ab,c,f
["Dm7b5",62,16,[68,72,79,10,14,15]], //ab,c,g
["Dm7b5",65,13,[72,74,80,14,16,10]], //c,d,ab
["Dm7b5",67,15,[72,74,80,14,16,10]], //c,d,ab
["DMaj#11",42,20,[45,49,56,17,21,22]], //f# a c# g#
["DMaj#5",50,16,[54,58,64,20,12,18]], //d f# bb e
["DMaj#5",50,16,[58,61,66,12,21,20]], //d bb c# f#
["DMajb13",54,20,[58,62,69,12,16,17]], //d f# bb a
["DmMaj7",45,17,[50,53,59,16,13,19]], //a d f b
["DmMaj7",49,21,[53,57,67,13,17,15]], //f c# a g
["DmMaj7",57,17,[62,65,73,16,13,21]], //d,f,c#
["DmMaj7",57,17,[64,65,73,18,13,21]], //e,f,c#
["DmMaj7",61,21,[65,69,74,13,17,16]], //f,a,d
["DmMaj7",61,21,[65,69,76,13,17,18]], //f,a,e
["DmMaj7",62,16,[69,73,77,17,21,13]], //a,c#,f
["DmMaj7",64,18,[69,73,77,17,21,13]], //a,c#,f
["DmMaj7",65,13,[73,74,81,21,16,17]], //c#,d,a
["DmMaj7",65,13,[73,76,81,21,18,17]], //c#,e,a
["E",44,22,[49,54,60,21,20,14]], //g# c# f# c
["E",52,18,[56,61,66,22,21,20]], //e g# c# f#
["E",52,18,[59,61,70,19,21,12]], //e b c# bb
["E",54,20,[60,64,69,14,18,17]], //e c f# a
["E",56,22,[63,64,71,23,18,19]], //d#,e,b
["E",59,19,[64,68,73,18,22,21]], //e,g#,c#
["E",59,19,[64,68,75,18,22,23]], //e,g#,d#
["E",61,21,[68,71,76,22,19,18]], //g#,b,e
["E",63,23,[68,71,76,22,19,18]], //g#,b,e
["E",64,18,[71,73,80,19,21,22]], //b,c#,g#
["E",64,18,[71,75,80,19,23,22]], //b,d#,g#
["E",68,22,[73,76,83,21,18,19]], //c#,e,b
["E6",44,22,[49,54,59,21,20,19]], //c# f# g# b
["E6",49,21,[52,59,63,18,19,23]], //e c# b d#
["E6",49,21,[56,59,66,22,19,20]], //g# b c# f#
["E7",44,22,[50,52,60,16,18,14]], //d e g# c
["E7",50,16,[56,60,63,22,14,23]], //d g# c d#
["E7",52,18,[59,62,68,19,16,22]], //b,d,g#
["E7",52,18,[59,62,69,19,16,17]], //e b d a
["E7",52,18,[59,62,69,19,16,17]], //e b d a
["E7",54,20,[61,62,68,21,16,22]], //c#,d,g#
["E7",56,22,[62,64,70,16,18,12]], //e g# d bb
["E7",56,22,[62,64,71,16,18,19]], //d,e,b
["E7",56,22,[62,64,72,16,18,14]], //e d g# c
["E7",56,22,[62,66,73,16,20,21]], //d,f#,c#
["E7",59,19,[64,68,74,18,22,16]], //e,g#,d
["E7",61,21,[66,68,74,20,22,16]], //f#,g#,d
["E7",62,16,[68,71,76,22,19,18]], //g#,b,e
["E7",62,16,[68,73,78,22,21,20]], //g#,c#,f#
["E7#11",50,16,[56,58,65,22,12,13]], //d g# bb f
["E7#11",50,16,[56,58,66,22,24,20]], //g#,a#,f#
["E7#11",54,20,[58,62,68,24,16,22]], //a#,d,g#
["E7#11",56,22,[62,64,70,16,18,24]], //d,e,a#
["E7#11",56,22,[62,66,70,16,20,24]], //d,f#,a#
["E7#11",58,12,[62,64,73,16,18,21]], //bb d e c#
["E7#11",58,12,[64,68,72,18,22,14]], //bb e g# c
["E7#11",58,24,[64,68,74,18,22,16]], //e,g#,d
["E7#11",58,24,[66,68,74,20,22,16]], //f#,g#,d
["E7#11",62,16,[68,70,76,22,24,18]], //g#,a#,e
["E7#11",64,18,[70,74,80,24,16,22]], //a#,d,g#
["E7b13",50,16,[59,60,64,19,14,18]], //b,c,e
["E7b13",52,18,[60,62,71,14,16,19]], //c,d,b
["E7b13",54,20,[60,62,68,14,16,22]], //c,d,g#
["E7b13",56,22,[62,66,72,16,20,14]], //d,f#,c
["E7b13",59,19,[62,64,72,16,18,14]], //d,e,c
["E7b13",60,14,[64,71,74,18,19,16]], //e,b,d
["E7b13",60,14,[66,68,74,20,22,16]], //f#,g#,d
["E7b13",62,16,[68,72,78,22,14,20]], //g#,c,f#
["E7b9",53,13,[61,62,68,21,16,22]], //c#,d,g#
["E7b9",56,22,[62,65,73,16,25,21]], //d,e#,c#
["E7b9",61,21,[65,68,74,25,22,16]], //e#,g#,d
["E7b9",62,16,[68,73,77,22,21,25]], //g#,c#,e#
["E7sus",50,16,[57,59,64,17,19,18]], //a,b,e
["E7sus",50,16,[57,61,64,17,21,18]], //a,c#,e
["E7sus",52,18,[57,62,66,17,16,20]], //a,d,f#
["E7sus",52,18,[57,62,68,17,16,22]], //e a d g#
["E7sus",52,18,[59,62,69,19,16,17]], //b,d,a
["E7sus",52,18,[61,62,69,21,16,17]], //c#,d,a
["E7sus",54,20,[62,64,69,16,18,17]], //d,e,a
["E7sus",57,17,[62,64,71,16,18,19]], //d,e,b
["E7sus",57,17,[62,64,73,16,18,21]], //d,e,c#
["E7sus",57,17,[64,66,74,18,20,16]], //e,f#,d
["E7sus",59,19,[64,69,74,18,17,16]], //e,a,d
["E7sus",61,21,[64,69,74,18,17,16]], //e,a,d
["E7sus",62,16,[66,69,76,20,17,18]], //f#,a,e
["E7susb9",52,18,[57,62,65,17,16,13]], //a,d,f
["E7susb9",53,25,[62,64,69,16,18,17]], //d,e,a
["E7susb9",57,17,[64,65,71,18,13,19]], //a e f b
["E7susb9",57,17,[64,65,74,18,25,16]], //e,e#,d
["E7susb9",62,16,[65,69,76,25,17,18]], //e#,a,e
["Eb",43,15,[48,53,59,14,13,19]], //g c f b
["Eb",51,11,[55,60,65,15,14,13]], //eb g c f
["Eb",51,11,[58,60,69,12,14,17]], //eb bb c a
["Eb",53,13,[59,63,68,19,11,10]], //eb b f ab
["Eb",55,15,[62,63,70,16,11,12]], //d,eb,bb
["Eb",58,12,[63,67,72,11,15,14]], //eb,g,c
["Eb",58,12,[63,67,74,11,15,16]], //eb,g,d
["Eb",60,14,[67,70,75,15,12,11]], //g,bb,eb
["Eb",62,16,[67,70,75,15,12,11]], //g,bb,eb
["Eb",63,11,[70,72,79,12,14,15]], //bb,c,g
["Eb",63,11,[70,74,79,12,16,15]], //bb,d,g
["Eb",67,15,[72,75,82,14,11,12]], //c,eb,bb
["Eb6",43,15,[48,53,58,14,13,12]], //c f g bb
["Eb6",48,14,[51,58,62,11,12,16]], //eb c bb d
["Eb6",48,14,[55,58,65,15,12,13]], //g bb c f
["Eb7",43,15,[49,51,59,9,11,19]], //db eb g b
["Eb7",49,9,[55,59,62,15,19,16]], //db g b d
["Eb7",51,11,[58,61,67,12,9,15]], //bb,db,g
["Eb7",51,11,[58,61,68,12,21,10]], //eb bb c# ab
["Eb7",51,11,[58,61,68,12,9,10]], //eb bb db ab
["Eb7",53,13,[60,61,67,14,9,15]], //c,db,g
["Eb7",55,15,[61,63,69,9,11,17]], //eb g db a
["Eb7",55,15,[61,63,70,9,11,12]], //db,eb,bb
["Eb7",55,15,[61,63,71,9,11,19]], //eb db g b
["Eb7",55,15,[61,65,72,9,13,14]], //db,f,c
["Eb7",58,12,[63,67,73,11,15,9]], //eb,g,db
["Eb7",60,14,[65,67,73,13,15,9]], //f,g,db
["Eb7",61,9,[67,70,75,15,12,11]], //g,bb,eb
["Eb7",61,9,[67,72,77,15,14,13]], //g,c,f
["Eb7#11",49,9,[55,57,64,15,17,18]], //db g a e
["Eb7#11",49,9,[55,57,65,15,17,13]], //g,a,f
["Eb7#11",53,13,[57,61,67,17,9,15]], //a,db,g
["Eb7#11",55,15,[61,63,69,9,11,17]], //db,eb,a
["Eb7#11",55,15,[61,65,69,9,13,17]], //db,f,a
["Eb7#11",57,17,[61,63,72,9,11,14]], //a db eb c
["Eb7#11",57,17,[63,67,71,11,15,19]], //a eb g b
["Eb7#11",57,17,[63,67,73,11,15,9]], //eb,g,db
["Eb7#11",57,17,[65,67,73,13,15,9]], //f,g,db
["Eb7#11",61,9,[67,69,75,15,17,11]], //g,a,eb
["Eb7#11",63,11,[69,73,79,17,9,15]], //a,db,g
["Eb7b13",49,9,[58,59,63,12,7,11]], //bb,cb,eb
["Eb7b13",51,11,[59,61,70,7,9,12]], //cb,db,bb
["Eb7b13",53,13,[59,61,67,7,9,15]], //cb,db,g
["Eb7b13",55,15,[61,65,71,9,13,7]], //db,f,cb
["Eb7b13",58,12,[61,63,71,9,11,7]], //db,eb,cb
["Eb7b13",59,7,[63,70,73,11,12,9]], //eb,bb,db
["Eb7b13",59,7,[65,67,73,13,15,9]], //f,g,db
["Eb7b13",61,9,[67,71,77,15,7,13]], //g,cb,f
["Eb7b9",52,6,[60,61,67,14,9,15]], //c,db,g
["Eb7b9",55,15,[61,64,72,9,18,14]], //db,e,c
["Eb7b9",60,14,[64,67,73,18,15,9]], //e,g,db
["Eb7b9",61,9,[67,72,76,15,14,18]], //g,c,e
["Eb7sus",49,9,[56,58,63,10,12,11]], //ab,bb,eb
["Eb7sus",49,9,[56,60,63,10,14,11]], //ab,c,eb
["Eb7sus",51,11,[56,61,65,10,9,13]], //ab,db,f
["Eb7sus",51,11,[56,61,67,10,9,15]], //eb ab db g
["Eb7sus",51,11,[58,61,68,12,9,10]], //bb,db,ab
["Eb7sus",51,11,[60,61,68,14,9,10]], //c,db,ab
["Eb7sus",53,13,[61,63,68,9,11,10]], //db,eb,ab
["Eb7sus",56,10,[61,63,70,9,11,12]], //db,eb,bb
["Eb7sus",56,10,[61,63,72,9,11,14]], //db,eb,c
["Eb7sus",56,10,[63,65,73,11,13,9]], //eb,f,db
["Eb7sus",58,12,[63,68,73,11,10,9]], //eb,ab,db
["Eb7sus",60,14,[63,68,73,11,10,9]], //eb,ab,db
["Eb7sus",61,9,[65,68,75,13,10,11]], //f,ab,eb
["Eb7susb9",51,11,[56,61,64,10,9,6]], //ab,db,fb
["Eb7susb9",52,18,[61,63,68,9,11,10]], //db,eb,ab
["Eb7susb9",56,10,[63,64,70,11,18,12]], //ab eb e bb
["Eb7susb9",56,10,[63,64,73,11,18,9]], //eb,e,db
["Eb7susb9",61,9,[64,68,75,18,10,11]], //e,ab,eb
["Ebm6",46,12,[51,54,60,11,8,14]], //bb eb gb c
["Ebm6",48,14,[51,58,66,11,12,8]], //eb bb c gb
["Ebm6",48,14,[54,58,63,8,12,11]], //c gb bb eb
["Ebm6",48,14,[54,58,63,8,12,11]], //c gb bb eb
["Ebm6",48,14,[54,58,64,8,12,18]], //gb c bb e
["Ebm6",48,14,[54,58,65,8,12,13]], //c gb bb f
["Ebm6",54,8,[60,63,70,14,11,12]], //c gb eb bb
["Ebm7",42,8,[49,51,57,9,11,17]], //gb db eb a
["Ebm7",46,12,[51,54,59,11,8,19]], //bb eb gb b
["Ebm7",46,12,[51,54,62,11,8,16]], //bb eb gb d
["Ebm7",49,9,[54,58,64,8,12,18]], //db gb bb e
["Ebm7",54,8,[60,63,70,14,11,12]], //c,eb,bb
["Ebm7",54,8,[61,63,68,9,11,10]], //db,eb,ab
["Ebm7",54,8,[61,63,70,9,11,12]], //db,eb,bb
["Ebm7",56,10,[63,66,73,11,8,9]], //eb,gb,db
["Ebm7",58,12,[63,66,72,11,8,14]], //eb,gb,c
["Ebm7",58,12,[63,66,73,11,8,9]], //eb,gb,db
["Ebm7",58,12,[65,66,73,13,8,9]], //f,gb,db
["Ebm7",60,14,[66,70,75,8,12,11]], //gb,bb,eb
["Ebm7",61,9,[66,68,75,8,10,11]], //gb,ab,eb
["Ebm7",61,9,[66,70,75,8,12,11]], //gb,bb,eb
["Ebm7",61,9,[66,70,77,8,12,13]], //gb,bb,f
["Ebm7",63,11,[68,73,78,10,9,8]], //ab,db,gb
["Ebm7",63,11,[70,72,78,12,14,8]], //bb,c,gb
["Ebm7",63,11,[70,73,78,12,9,8]], //bb,db,gb
["Ebm7",65,13,[70,73,78,12,9,8]], //bb,db,gb
["Ebm7",66,8,[73,77,82,9,13,12]], //db,f,bb
["Ebm7#5",39,11,[47,49,54,19,9,8]], //eb b db gb
["Ebm7#5",49,9,[54,59,63,8,19,11]], //gb db b eb
["Ebm7#5",51,11,[54,59,65,8,19,13]], //eb gb b f
["Ebm7b5",45,17,[51,54,62,11,8,16]], //A eb gb d
["Ebm7b5",49,9,[54,57,64,8,17,18]], //a gb db e
["Ebm7b5",51,11,[54,57,65,8,17,13]], //eb gb A f
["EbMaj#11",43,15,[46,50,57,12,16,17]], //g bb d a
["EbMaj#5",51,11,[55,59,65,15,19,13]], //eb g b f
["EbMaj#5",51,11,[59,62,67,19,16,15]], //eb b d g
["EbMajb13",55,15,[59,63,70,19,11,12]], //eb g b bb
["EbmMaj7",46,12,[51,54,60,11,8,14]], //bb eb gb c
["EbmMaj7",50,16,[54,58,68,8,12,10]], //gb d bb ab
["EbmMaj7",58,12,[63,66,74,11,8,16]], //eb,gb,d
["EbmMaj7",58,12,[65,66,74,13,8,16]], //f,gb,d
["EbmMaj7",62,16,[66,70,75,8,12,11]], //gb,bb,eb
["EbmMaj7",62,16,[66,70,77,8,12,13]], //gb,bb,f
["EbmMaj7",63,11,[70,74,78,12,16,8]], //bb,d,gb
["EbmMaj7",65,13,[70,74,78,12,16,8]], //bb,d,gb
["EbmMaj7",66,8,[74,75,82,16,11,12]], //d,eb,bb
["EbmMaj7",66,8,[74,77,82,16,13,12]], //d,f,bb
["Em6",47,19,[52,55,61,18,15,21]], //b e g c#
["Em6",49,21,[52,59,67,18,19,15]], //e b c# g
["Em6",49,21,[55,59,64,15,19,18]], //c# g b e
["Em6",49,21,[55,59,64,15,19,18]], //c# g b e
["Em6",49,21,[55,59,65,15,19,13]], //g c# b f
["Em6",49,21,[55,59,66,15,19,20]], //c# g b f#
["Em6",55,15,[61,64,71,21,18,19]], //c# g e b
["Em7",43,15,[50,52,58,16,18,12]], //g d e bb
["Em7",47,19,[52,55,60,18,15,14]], //b e g c
["Em7",47,19,[52,55,63,18,15,11]], //b e g eb
["Em7",50,16,[55,59,65,15,19,13]], //d g b f
["Em7",55,15,[61,64,71,21,18,19]], //c#,e,b
["Em7",55,15,[62,64,69,16,18,17]], //d,e,a
["Em7",55,15,[62,64,71,16,18,19]], //d,e,b
["Em7",57,17,[64,67,74,18,15,16]], //e,g,d
["Em7",59,19,[64,67,73,18,15,21]], //e,g,c#
["Em7",59,19,[64,67,74,18,15,16]], //e,g,d
["Em7",59,19,[66,67,74,20,15,16]], //f#,g,d
["Em7",61,21,[67,71,76,15,19,18]], //g,b,e
["Em7",62,16,[67,69,76,15,17,18]], //g,a,e
["Em7",62,16,[67,71,76,15,19,18]], //g,b,e
["Em7",62,16,[67,71,78,15,19,20]], //g,b,f#
["Em7",64,18,[69,74,79,17,16,15]], //a,d,g
["Em7",64,18,[71,73,79,19,21,15]], //b,c#,g
["Em7",64,18,[71,74,79,19,16,15]], //b,d,g
["Em7",66,20,[71,74,79,19,16,15]], //b,d,g
["Em7",67,15,[74,78,83,16,20,19]], //d,f#,b
["Em7#5",40,18,[48,50,55,14,16,15]], //e c d g
["Em7#5",50,16,[55,60,64,15,14,18]], //g d c e
["Em7#5",52,18,[55,60,66,15,14,20]], //e g c f#
["Em7b5",46,12,[52,55,63,18,15,11]], //bb e g eb
["Em7b5",50,16,[55,58,65,15,12,13]], //bb g d f
["Em7b5",52,18,[55,58,66,15,12,20]], //e g bb f#
["Em7b5",58,12,[64,67,74,18,15,16]], //e,g,d
["Em7b5",58,12,[64,69,74,18,17,16]], //e,a,d
["Em7b5",62,16,[67,70,76,15,12,18]], //g,bb,e
["Em7b5",62,16,[69,70,76,17,12,18]], //a,bb,e
["Em7b5",64,18,[70,74,79,12,16,15]], //bb,d,g
["Em7b5",64,18,[70,74,81,12,16,17]], //bb,d,a
["Em7b5",67,15,[74,76,82,16,18,12]], //d,e,bb
["Em7b5",69,17,[74,76,82,16,18,12]], //d,e,bb
["EMaj#11",44,22,[47,51,58,19,23,24]], //g# b d# a#
["EMaj#5",52,18,[56,60,66,22,14,20]], //e g# c f#
["EMaj#5",52,18,[60,63,68,14,23,22]], //e c d# g#
["EMajb13",56,22,[60,64,71,14,18,19]], //e g# c b
["EmMaj7",47,19,[52,55,61,18,15,21]], //b e g c#
["EmMaj7",51,23,[55,59,69,15,19,17]], //g d# b a
["EmMaj7",59,19,[64,67,75,18,15,23]], //e,g,d#
["EmMaj7",59,19,[66,67,75,20,15,23]], //f#,g,d#
["EmMaj7",63,23,[67,71,76,15,19,18]], //g,b,e
["EmMaj7",63,23,[67,71,78,15,19,20]], //g,b,f#
["EmMaj7",64,18,[71,75,79,19,23,15]], //b,d#,g
["EmMaj7",66,20,[71,75,79,19,23,15]], //b,d#,g
["EmMaj7",67,15,[75,76,83,23,18,19]], //d#,e,b
["EmMaj7",67,15,[75,78,83,23,20,19]], //d#,f#,b
["F",45,17,[50,55,61,16,15,21]], //a d g c#
["F",53,13,[57,62,67,17,16,15]], //f a d g
["F",53,13,[60,62,71,14,16,19]], //f c d b
["F",55,15,[61,65,70,9,13,12]], //f db g bb
["F",57,17,[64,65,72,18,13,14]], //e,f,c
["F",60,14,[65,69,74,13,17,16]], //f,a,d
["F",60,14,[65,69,76,13,17,18]], //f,a,e
["F",62,16,[69,72,77,17,14,13]], //a,c,f
["F",64,18,[69,72,77,17,14,13]], //a,c,f
["F",65,13,[72,74,81,14,16,17]], //c,d,a
["F",65,13,[72,76,81,14,18,17]], //c,e,a
["F",69,17,[74,77,84,16,13,14]], //d,f,c
["F#7",54,20,[61,64,70,21,18,24]], //c#,e,a#
["F#7",56,22,[63,64,70,23,18,24]], //d#,e,a#
["F#7",58,24,[64,66,73,18,20,21]], //e,f#,c#
["F#7",58,24,[64,68,75,18,22,23]], //e,g#,d#
["F#7",61,21,[66,70,76,20,24,18]], //f#,a#,e
["F#7",63,23,[68,70,76,22,24,18]], //g#,a#,e
["F#7",64,18,[70,73,78,24,21,20]], //a#,c#,f#
["F#7",64,18,[70,75,80,24,23,22]], //a#,d#,g#
["F#7#11",52,18,[58,60,68,24,26,22]], //a#,b#,g#
["F#7#11",56,22,[60,64,70,26,18,24]], //b#,e,a#
["F#7#11",58,24,[64,66,72,18,20,26]], //e,f#,b#
["F#7#11",58,24,[64,68,72,18,22,26]], //e,g#,b#
["F#7#11",60,26,[66,70,76,20,24,18]], //f#,a#,e
["F#7#11",60,26,[68,70,76,22,24,18]], //g#,a#,e
["F#7#11",64,18,[70,72,78,24,26,20]], //a#,b#,f#
["F#7#11",66,20,[72,76,82,26,18,24]], //b#,e,a#
["F#7b13",52,18,[61,62,66,21,16,20]], //c#,d,f#
["F#7b13",54,20,[62,64,73,16,18,21]], //d,e,c#
["F#7b13",56,22,[62,64,70,16,18,24]], //d,e,a#
["F#7b13",58,24,[64,68,74,18,22,16]], //e,g#,d
["F#7b13",61,21,[64,66,74,18,20,16]], //e,f#,d
["F#7b13",62,16,[66,73,76,20,21,18]], //f#,c#,e
["F#7b13",62,16,[68,70,76,22,24,18]], //g#,a#,e
["F#7b13",64,18,[70,74,80,24,16,22]], //a#,d,g#
["F#7b9",55,15,[63,64,70,23,18,24]], //d#,e,a#
["F#7b9",58,24,[64,67,75,18,15,23]], //e,g,d#
["F#7b9",63,23,[67,70,76,15,24,18]], //g,a#,e
["F#7b9",64,18,[70,75,79,24,23,15]], //a#,d#,g
["F#7sus",52,18,[59,61,66,19,21,20]], //b,c#,f#
["F#7sus",52,18,[59,63,66,19,23,20]], //b,d#,f#
["F#7sus",54,20,[59,64,68,19,18,22]], //b,e,g#
["F#7sus",54,20,[61,64,71,21,18,19]], //c#,e,b
["F#7sus",54,20,[63,64,71,23,18,19]], //d#,e,b
["F#7sus",56,22,[64,66,71,18,20,19]], //e,f#,b
["F#7sus",59,19,[64,66,73,18,20,21]], //e,f#,c#
["F#7sus",59,19,[64,66,75,18,20,23]], //e,f#,d#
["F#7sus",59,19,[66,68,76,20,22,18]], //f#,g#,e
["F#7sus",61,21,[66,71,76,20,19,18]], //f#,b,e
["F#7sus",63,23,[66,71,76,20,19,18]], //f#,b,e
["F#7sus",64,18,[68,71,78,22,19,20]], //g#,b,f#
["F#7susb9",54,20,[59,64,67,19,18,15]], //b,e,g
["F#7susb9",55,15,[64,66,71,18,20,19]], //e,f#,b
["F#7susb9",59,19,[66,67,76,20,15,18]], //f#,g,e
["F#7susb9",64,18,[67,71,78,15,19,20]], //g,b,f#
["F#m7",57,17,[63,66,73,23,20,21]], //d#,f#,c#
["F#m7",57,17,[64,66,71,18,20,19]], //e,f#,b
["F#m7",57,17,[64,66,73,18,20,21]], //e,f#,c#
["F#m7",59,19,[66,69,76,20,17,18]], //f#,a,e
["F#m7",61,21,[66,69,75,20,17,23]], //f#,a,d#
["F#m7",61,21,[66,69,76,20,17,18]], //f#,a,e
["F#m7",61,21,[68,69,76,22,17,18]], //g#,a,e
["F#m7",63,23,[69,73,78,17,21,20]], //a,c#,f#
["F#m7",64,18,[69,71,78,17,19,20]], //a,b,f#
["F#m7",64,18,[69,73,78,17,21,20]], //a,c#,f#
["F#m7",64,18,[69,73,80,17,21,22]], //a,c#,g#
["F#m7",66,20,[71,76,81,19,18,17]], //b,e,a
["F#m7",66,20,[73,75,81,21,23,17]], //c#,d#,a
["F#m7",66,20,[73,76,81,21,18,17]], //c#,e,a
["F#m7",68,22,[73,76,81,21,18,17]], //c#,e,a
["F#m7",69,17,[76,80,85,18,22,21]], //e,g#,c#
["F#m7b5",60,14,[66,69,76,20,17,18]], //f#,a,e
["F#m7b5",60,14,[66,71,76,20,19,18]], //f#,b,e
["F#m7b5",64,18,[69,72,78,17,14,20]], //a,c,f#
["F#m7b5",64,18,[71,72,78,19,14,20]], //b,c,f#
["F#m7b5",66,20,[72,76,81,14,18,17]], //c,e,a
["F#m7b5",66,20,[72,76,83,14,18,19]], //c,e,b
["F#m7b5",69,17,[76,78,84,18,20,14]], //e,f#,c
["F#m7b5",71,19,[76,78,84,18,20,14]], //e,f#,c
["F6",45,17,[50,55,60,16,15,14]], //d g a c
["F6",50,16,[53,60,64,13,14,18]], //f d c e
["F6",50,16,[57,60,67,17,14,15]], //a c d g
["F7",45,17,[51,53,61,11,13,21]], //eb f a c#
["F7",51,11,[57,61,64,17,9,18]], //eb a db e
["F7",53,13,[60,63,69,14,11,17]], //c,eb,a
["F7",53,13,[60,63,70,14,11,12]], //f c eb bb
["F7",53,13,[60,63,70,14,23,12]], //f c d# bb
["F7",55,15,[62,63,69,16,11,17]], //d,eb,a
["F7",57,17,[63,65,71,11,13,19]], //f a eb b
["F7",57,17,[63,65,72,11,13,14]], //eb,f,c
["F7",57,17,[63,65,73,11,13,9]], //f eb a db
["F7",57,17,[63,67,74,11,15,16]], //eb,g,d
["F7",60,14,[65,69,75,13,17,11]], //f,a,eb
["F7",62,16,[67,69,75,15,17,11]], //g,a,eb
["F7",63,11,[69,72,77,17,14,13]], //a,c,f
["F7",63,11,[69,74,79,17,16,15]], //a,d,g
["F7#11",51,11,[57,59,66,17,19,20]], //eb a b f#
["F7#11",51,11,[57,59,67,17,19,15]], //a,b,g
["F7#11",55,15,[59,63,69,19,11,17]], //b,eb,a
["F7#11",57,17,[63,65,71,11,13,19]], //eb,f,b
["F7#11",57,17,[63,67,71,11,15,19]], //eb,g,b
["F7#11",59,19,[63,65,74,11,13,16]], //b eb f d
["F7#11",59,19,[65,69,73,13,17,9]], //b f a db
["F7#11",59,19,[65,69,75,13,17,11]], //f,a,eb
["F7#11",59,19,[67,69,75,15,17,11]], //g,a,eb
["F7#11",63,11,[69,71,77,17,19,13]], //a,b,f
["F7#11",65,13,[71,75,81,19,11,17]], //b,eb,a
["F7b13",51,11,[60,61,65,14,9,13]], //c,db,f
["F7b13",53,13,[61,63,72,9,11,14]], //db,eb,c
["F7b13",55,15,[61,63,69,9,11,17]], //db,eb,a
["F7b13",57,17,[63,67,73,11,15,9]], //eb,g,db
["F7b13",60,14,[63,65,73,11,13,9]], //eb,f,db
["F7b13",61,9,[65,72,75,13,14,11]], //f,c,eb
["F7b13",61,9,[67,69,75,15,17,11]], //g,a,eb
["F7b13",63,11,[69,73,79,17,9,15]], //a,db,g
["F7b9",54,8,[62,63,69,16,11,17]], //d,eb,a
["F7b9",57,17,[63,66,74,11,20,16]], //eb,f#,d
["F7b9",62,16,[66,69,75,20,17,11]], //f#,a,eb
["F7b9",63,11,[69,74,78,17,16,20]], //a,d,f#
["F7sus",51,11,[58,60,65,12,14,13]], //bb,c,f
["F7sus",51,11,[58,62,65,12,16,13]], //bb,d,f
["F7sus",53,13,[58,63,67,12,11,15]], //bb,eb,g
["F7sus",53,13,[58,63,69,12,11,17]], //f bb eb a
["F7sus",53,13,[60,63,70,14,11,12]], //c,eb,bb
["F7sus",53,13,[62,63,70,16,11,12]], //d,eb,bb
["F7sus",55,15,[63,65,70,11,13,12]], //eb,f,bb
["F7sus",58,12,[63,65,72,11,13,14]], //eb,f,c
["F7sus",58,12,[63,65,74,11,13,16]], //eb,f,d
["F7sus",58,12,[65,67,75,13,15,11]], //f,g,eb
["F7sus",60,14,[65,70,75,13,12,11]], //f,bb,eb
["F7sus",62,16,[65,70,75,13,12,11]], //f,bb,eb
["F7sus",63,11,[67,70,77,15,12,13]], //g,bb,f
["F7susb9",53,13,[58,63,66,12,11,8]], //bb,eb,gb
["F7susb9",54,20,[63,65,70,11,13,12]], //eb,f,bb
["F7susb9",58,12,[65,66,72,13,8,14]], //bb f gb c
["F7susb9",58,12,[65,66,75,13,20,11]], //f,f#,eb
["F7susb9",63,11,[66,70,77,20,12,13]], //f#,bb,f
["Fm6",48,14,[53,56,62,13,10,16]], //c f ab d
["Fm6",50,16,[53,60,68,13,14,10]], //f c d ab
["Fm6",50,16,[56,60,65,10,14,13]], //d ab c f
["Fm6",50,16,[56,60,65,10,14,13]], //d ab c f
["Fm6",50,16,[56,60,66,10,14,8]], //ab d c gb
["Fm6",50,16,[56,60,67,10,14,15]], //d ab c g
["Fm6",56,10,[62,65,72,16,13,14]], //d ab f c
["Fm7",44,10,[51,53,59,11,13,19]], //ab eb f b
["Fm7",48,14,[53,56,61,13,10,9]], //c f ab db
["Fm7",48,14,[53,56,64,13,10,18]], //c f ab e
["Fm7",51,11,[56,60,66,10,14,8]], //eb ab c gb
["Fm7",56,10,[62,65,72,16,13,14]], //d,f,c
["Fm7",56,10,[63,65,70,11,13,12]], //eb,f,bb
["Fm7",56,10,[63,65,72,11,13,14]], //eb,f,c
["Fm7",58,12,[65,68,75,13,10,11]], //f,ab,eb
["Fm7",60,14,[65,68,74,13,10,16]], //f,ab,d
["Fm7",60,14,[65,68,75,13,10,11]], //f,ab,eb
["Fm7",60,14,[67,68,75,15,10,11]], //g,ab,eb
["Fm7",62,16,[68,72,77,10,14,13]], //ab,c,f
["Fm7",63,11,[68,70,77,10,12,13]], //ab,bb,f
["Fm7",63,11,[68,72,77,10,14,13]], //ab,c,f
["Fm7",63,11,[68,72,79,10,14,15]], //ab,c,g
["Fm7",65,13,[70,75,80,12,11,10]], //bb,eb,ab
["Fm7",65,13,[72,74,80,14,16,10]], //c,d,ab
["Fm7",65,13,[72,75,80,14,11,10]], //c,eb,ab
["Fm7",67,15,[72,75,80,14,11,10]], //c,eb,ab
["Fm7",68,10,[75,79,84,11,15,14]], //eb,g,c
["Fm7#5",41,13,[49,51,56,9,11,10]], //f db eb ab
["Fm7#5",51,11,[56,61,65,10,9,13]], //ab eb db f
["Fm7#5",53,13,[56,61,67,10,9,15]], //f ab db g
["Fm7b5",47,19,[53,56,64,13,10,18]], //b f ab e
["Fm7b5",51,11,[56,59,66,10,19,8]], //b ab eb gb
["Fm7b5",53,13,[56,59,67,10,19,15]], //f ab b g
["Fm7b5",59,7,[65,68,75,13,10,11]], //f,ab,eb
["Fm7b5",59,7,[65,70,75,13,12,11]], //f,bb,eb
["Fm7b5",63,11,[68,71,77,10,7,13]], //ab,cb,f
["Fm7b5",63,11,[70,71,77,12,7,13]], //bb,cb,f
["Fm7b5",65,13,[71,75,80,7,11,10]], //cb,eb,ab
["Fm7b5",65,13,[71,75,82,7,11,12]], //cb,eb,bb
["Fm7b5",68,10,[75,77,83,11,13,7]], //eb,f,cb
["Fm7b5",70,12,[75,77,83,11,13,7]], //eb,f,cb
["FMaj#11",45,17,[48,52,59,14,18,19]], //a c e b
["FMaj#5",53,13,[57,61,67,17,21,15]], //f a c# g
["FMaj#5",53,13,[61,64,69,21,18,17]], //f c# e a
["FMajb13",57,17,[61,65,72,9,13,14]], //f a db c
["FmMaj7",48,14,[53,56,62,13,10,16]], //c f ab d
["FmMaj7",52,18,[56,60,70,10,14,12]], //ab e c bb
["FmMaj7",60,14,[65,68,76,13,10,18]], //f,ab,e
["FmMaj7",60,14,[67,68,76,15,10,18]], //g,ab,e
["FmMaj7",64,18,[68,72,77,10,14,13]], //ab,c,f
["FmMaj7",64,18,[68,72,79,10,14,15]], //ab,c,g
["FmMaj7",65,13,[72,76,80,14,18,10]], //c,e,ab
["FmMaj7",67,15,[72,76,80,14,18,10]], //c,e,ab
["FmMaj7",68,10,[76,77,84,18,13,14]], //e,f,c
["FmMaj7",68,10,[76,79,84,18,15,14]], //e,g,c
["G",47,19,[52,57,63,18,17,11]], //b e a eb
["G",55,15,[59,64,69,19,18,17]], //g b e a
["G",55,15,[62,64,73,16,18,21]], //g d e c#
["G",57,17,[63,67,72,11,15,14]], //g eb a c
["G",59,19,[66,67,74,20,15,16]], //f#,g,d
["G",62,16,[67,71,76,15,19,18]], //g,b,e
["G",62,16,[67,71,78,15,19,20]], //g,b,f#
["G",64,18,[71,74,79,19,16,15]], //b,d,g
["G",66,20,[71,74,79,19,16,15]], //b,d,g
["G",67,15,[74,76,83,16,18,19]], //d,e,b
["G",67,15,[74,78,83,16,20,19]], //d,f#,b
["G",71,19,[76,79,86,18,15,16]], //e,g,d
["G#m7b5",50,16,[56,59,66,22,19,20]], //g#,b,f#
["G#m7b5",50,16,[56,61,66,22,21,20]], //g#,c#,f#
["G#m7b5",54,20,[59,62,68,19,16,22]], //b,d,g#
["G#m7b5",54,20,[61,62,68,21,16,22]], //c#,d,g#
["G#m7b5",56,22,[62,66,71,16,20,19]], //d,f#,b
["G#m7b5",56,22,[62,66,73,16,20,21]], //d,f#,c#
["G#m7b5",59,19,[66,68,74,20,22,16]], //f#,g#,d
["G#m7b5",61,21,[66,68,74,20,22,16]], //f#,g#,d
["G6",47,19,[52,57,62,18,17,16]], //e a b d
["G6",52,18,[55,62,66,15,16,20]], //g e d f#
["G6",52,18,[59,62,69,19,16,17]], //b d e a
["G7",47,19,[53,55,63,13,15,11]], //f g b eb
["G7",53,13,[59,63,66,19,11,20]], //f b eb f#
["G7",55,15,[62,65,71,16,13,19]], //d,f,b
["G7",55,15,[62,65,72,16,13,14]], //g d f c
["G7",55,15,[62,65,72,16,13,14]], //g d f c
["G7",57,17,[64,65,71,18,13,19]], //e,f,b
["G7",59,19,[65,67,73,13,15,21]], //g b f c#
["G7",59,19,[65,67,74,13,15,16]], //f,g,d
["G7",59,19,[65,67,75,13,15,11]], //g f b eb
["G7",59,19,[65,69,76,13,17,18]], //f,a,e
["G7",62,16,[67,71,77,15,19,13]], //g,b,f
["G7",64,18,[69,71,77,17,19,13]], //a,b,f
["G7",65,13,[71,74,79,19,16,15]], //b,d,g
["G7",65,13,[71,76,81,19,18,17]], //b,e,a
["G7#11",53,13,[59,61,68,19,9,10]], //f b db ab
["G7#11",53,13,[59,61,69,19,21,17]], //b,c#,a
["G7#11",57,17,[61,65,71,21,13,19]], //c#,f,b
["G7#11",59,19,[65,67,73,13,15,21]], //f,g,c#
["G7#11",59,19,[65,69,73,13,17,21]], //f,a,c#
["G7#11",61,21,[65,67,76,13,15,18]], //c# f g e
["G7#11",61,21,[67,71,75,15,19,11]], //c# g b eb
["G7#11",61,21,[67,71,77,15,19,13]], //g,b,f
["G7#11",61,21,[69,71,77,17,19,13]], //a,b,f
["G7#11",65,13,[71,73,79,19,21,15]], //b,c#,g
["G7#11",67,15,[73,77,83,21,13,19]], //c#,f,b
["G7b13",53,13,[62,63,67,16,11,15]], //d,eb,g
["G7b13",55,15,[63,65,74,11,13,16]], //eb,f,d
["G7b13",57,17,[63,65,71,11,13,19]], //eb,f,b
["G7b13",59,19,[65,69,75,13,17,11]], //f,a,eb
["G7b13",62,16,[65,67,75,13,15,11]], //f,g,eb
["G7b13",63,11,[67,74,77,15,16,13]], //g,d,f
["G7b13",63,11,[69,71,77,17,19,13]], //a,b,f
["G7b13",65,13,[71,75,81,19,11,17]], //b,eb,a
["G7b9",56,10,[64,65,71,18,13,19]], //e,f,b
["G7b9",59,19,[65,68,76,13,10,18]], //f,ab,e
["G7b9",64,18,[68,71,77,10,19,13]], //ab,b,f
["G7b9",65,13,[71,76,80,19,18,10]], //b,e,ab
["G7sus",53,13,[60,62,67,14,16,15]], //c,d,g
["G7sus",53,13,[60,64,67,14,18,15]], //c,e,g
["G7sus",55,15,[60,65,69,14,13,17]], //c,f,a
["G7sus",55,15,[60,65,71,14,13,19]], //g c f b
["G7sus",55,15,[62,65,72,16,13,14]], //d,f,c
["G7sus",55,15,[64,65,72,18,13,14]], //e,f,c
["G7sus",57,17,[65,67,72,13,15,14]], //f,g,c
["G7sus",60,14,[65,67,74,13,15,16]], //f,g,d
["G7sus",60,14,[65,67,76,13,15,18]], //f,g,e
["G7sus",60,14,[67,69,77,15,17,13]], //g,a,f
["G7sus",62,16,[67,72,77,15,14,13]], //g,c,f
["G7sus",64,18,[67,72,77,15,14,13]], //g,c,f
["G7sus",65,13,[69,72,79,17,14,15]], //a,c,g
["G7susb9",55,15,[60,65,68,14,13,10]], //c,f,ab
["G7susb9",56,10,[65,67,72,13,15,14]], //f,g,c
["G7susb9",60,14,[67,68,74,15,10,16]], //c g ab d
["G7susb9",60,14,[67,68,77,15,10,13]], //g,ab,f
["G7susb9",65,13,[68,72,79,10,14,15]], //ab,c,g
["Gb",46,12,[51,56,62,11,10,16]], //bb eb ab d
["Gb",54,8,[58,63,68,12,11,10]], //gb bb eb ab
["Gb",54,8,[61,63,72,9,11,14]], //gb db eb c
["Gb",56,10,[62,66,71,16,8,19]], //gb d ab b
["Gb",58,12,[65,66,73,13,8,9]], //f,gb,db
["Gb",61,9,[66,70,75,8,12,11]], //gb,bb,eb
["Gb",61,9,[66,70,77,8,12,13]], //gb,bb,f
["Gb",63,11,[70,73,78,12,9,8]], //bb,db,gb
["Gb",65,13,[70,73,78,12,9,8]], //bb,db,gb
["Gb",66,8,[73,75,82,9,11,12]], //db,eb,bb
["Gb",66,8,[73,77,82,9,13,12]], //db,f,bb
["Gb",70,12,[75,78,85,11,8,9]], //eb,gb,db
["Gb6",46,12,[51,56,61,11,10,9]], //eb ab bb db
["Gb6",51,11,[54,61,65,8,9,13]], //gb eb db f
["Gb6",51,11,[58,61,68,12,9,10]], //bb db eb ab
["Gb7",46,12,[52,54,62,18,8,16]], //e gb bb d
["Gb7",52,18,[58,62,65,12,16,13]], //e bb d f
["Gb7",54,8,[61,64,71,9,18,19]], //gb db e b
["Gb7",54,8,[61,64,71,9,18,19]], //gb db e b
["Gb7",58,12,[64,66,72,18,8,14]], //gb bb e c
["Gb7",58,12,[64,66,74,18,8,16]], //gb e bb d
["Gb7#11",52,18,[58,60,67,12,14,15]], //e bb c g
["Gb7#11",60,14,[64,66,75,18,8,11]], //c e gb eb
["Gb7#11",60,14,[66,70,74,8,12,16]], //c gb bb d
["Gb7sus",54,8,[59,64,70,19,18,12]], //gb b e bb
["Gb7susb9",59,19,[66,67,73,8,15,9]], //b gb g db
["Gbm6",49,21,[54,57,63,20,17,23]], //c# f# a d#
["Gbm6",51,11,[54,61,69,8,9,17]], //gb db eb A
["Gbm6",51,11,[57,61,68,17,9,10]], //eb A db ab
["Gbm6",51,23,[57,61,66,17,21,20]], //d# a c# f#
["Gbm6",51,23,[57,61,66,17,21,20]], //d# a c# f#
["Gbm6",51,23,[57,61,67,17,21,15]], //a d# c# g
["Gbm6",57,17,[63,66,73,23,20,21]], //d# a f# c#
["Gbm7",45,17,[52,54,60,18,20,14]], //a e f# c
["Gbm7",49,21,[54,57,62,20,17,16]], //c# f# a d
["Gbm7",49,21,[54,57,65,20,17,13]], //c# f# a f
["Gbm7",52,18,[57,61,67,17,21,15]], //e a c# g
["Gbm7#5",42,20,[50,52,57,16,18,17]], //f# d e a
["Gbm7#5",52,18,[57,62,66,17,16,20]], //a e d f#
["Gbm7#5",54,20,[57,62,68,17,16,22]], //f# a d g#
["Gbm7b5",48,14,[54,57,65,20,17,13]], //c f# a f
["Gbm7b5",52,18,[57,60,67,17,14,15]], //c a e g
["Gbm7b5",54,20,[57,60,68,17,14,22]], //f# a c g#
["GbMaj#11",46,12,[49,53,60,9,13,14]], //bb db f c
["GbMaj#5",54,8,[58,62,68,12,16,10]], //gb bb d ab
["GbMaj#5",54,8,[62,65,70,16,13,12]], //gb d f bb
["GbMajb13",58,12,[62,66,73,16,8,9]], //gb bb d db
["GbmMaj7",49,9,[54,57,63,8,17,11]], //db gb A eb
["GbmMaj7",53,13,[57,61,71,17,9,19]], //A f db b
["GbmMaj7",61,9,[66,69,77,8,17,13]], //gb,a,f
["GbmMaj7",61,9,[68,69,77,10,17,13]], //ab,a,f
["GbmMaj7",65,13,[69,73,78,17,9,8]], //a,db,gb
["GbmMaj7",65,13,[69,73,80,17,9,10]], //a,db,ab
["GbmMaj7",66,8,[73,77,81,9,13,17]], //db,f,a
["GbmMaj7",68,10,[73,77,81,9,13,17]], //db,f,a
["GbmMaj7",69,17,[77,78,85,13,8,9]], //f,gb,db
["GbmMaj7",69,17,[77,80,85,13,10,9]], //f,ab,db
["Gm6",50,16,[55,58,64,15,12,18]], //d g bb e
["Gm6",52,18,[55,62,70,15,16,12]], //g d e bb
["Gm6",52,18,[58,62,67,12,16,15]], //e bb d g
["Gm6",52,18,[58,62,67,12,16,15]], //e bb d g
["Gm6",52,18,[58,62,68,12,16,10]], //bb e d ab
["Gm6",52,18,[58,62,69,12,16,17]], //e bb d a
["Gm6",58,12,[64,67,74,18,15,16]], //e bb g d
["Gm7",46,12,[53,55,61,13,15,21]], //bb f g c#
["Gm7",50,16,[55,58,63,15,12,11]], //d g bb eb
["Gm7",50,16,[55,58,66,15,12,20]], //d g bb f#
["Gm7",53,13,[58,62,68,12,16,10]], //f bb d ab
["Gm7",58,12,[64,67,74,18,15,16]], //e,g,d
["Gm7",58,12,[65,67,72,13,15,14]], //f,g,c
["Gm7",58,12,[65,67,74,13,15,16]], //f,g,d
["Gm7",60,14,[67,70,77,15,12,13]], //g,bb,f
["Gm7",62,16,[67,70,76,15,12,18]], //g,bb,e
["Gm7",62,16,[67,70,77,15,12,13]], //g,bb,f
["Gm7",62,16,[69,70,77,17,12,13]], //a,bb,f
["Gm7",64,18,[70,74,79,12,16,15]], //bb,d,g
["Gm7",65,13,[70,72,79,12,14,15]], //bb,c,g
["Gm7",65,13,[70,74,79,12,16,15]], //bb,d,g
["Gm7",65,13,[70,74,81,12,16,17]], //bb,d,a
["Gm7",67,15,[72,77,82,14,13,12]], //c,f,bb
["Gm7",67,15,[74,76,82,16,18,12]], //d,e,bb
["Gm7",67,15,[74,77,82,16,13,12]], //d,f,bb
["Gm7",69,17,[74,77,82,16,13,12]], //d,f,bb
["Gm7",70,12,[77,81,86,13,17,16]], //f,a,d
["Gm7#5",43,15,[51,53,58,11,13,12]], //g eb f bb
["Gm7#5",53,13,[58,63,67,12,11,15]], //bb f eb g
["Gm7#5",55,15,[58,63,69,12,11,17]], //g bb eb a
["Gm7b5",49,9,[55,58,65,15,12,13]], //g,bb,f
["Gm7b5",49,9,[55,58,66,15,12,20]], //db g bb f#
["Gm7b5",49,9,[55,60,65,15,14,13]], //g,c,f
["Gm7b5",53,13,[58,61,67,12,9,15]], //bb,db,g
["Gm7b5",53,13,[58,61,68,12,9,10]], //db bb f ab
["Gm7b5",53,13,[60,61,67,14,9,15]], //c,db,g
["Gm7b5",55,15,[58,61,69,12,9,17]], //g bb db a
["Gm7b5",55,15,[61,65,70,9,13,12]], //db,f,bb
["Gm7b5",55,15,[61,65,72,9,13,14]], //db,f,c
["Gm7b5",58,12,[65,67,73,13,15,9]], //f,g,db
["Gm7b5",60,14,[65,67,73,13,15,9]], //f,g,db
["GMaj#11",47,19,[50,54,61,16,20,21]], //b d f# c#
["GMaj#5",55,15,[59,63,69,19,11,17]], //g b eb a
["GMaj#5",55,15,[63,66,71,11,20,19]], //g eb f# b
["GMajb13",59,19,[63,67,74,11,15,16]], //g b eb d  
["GmMaj7",50,16,[55,58,64,15,12,18]], //d g bb e
["GmMaj7",54,20,[58,62,72,12,16,14]], //bb f# d c
["GmMaj7",62,16,[67,70,78,15,12,20]], //g,bb,f#
["GmMaj7",62,16,[69,70,78,17,12,20]], //a,bb,f#
["GmMaj7",66,20,[70,74,79,12,16,15]], //bb,d,g
["GmMaj7",66,20,[70,74,81,12,16,17]], //bb,d,a
["GmMaj7",67,15,[74,78,82,16,20,12]], //d,f#,bb
["GmMaj7",69,17,[74,78,82,16,20,12]], //d,f#,bb
["GmMaj7",70,12,[78,79,86,20,15,16]], //f#,g,d
["GmMaj7",70,12,[78,81,86,20,17,16]], //f#,a,d
		];

		var melnotes = new Array(512);
		// melnotes
		// O: notename
		// 1: pitch
		// 2 : tick
		for (var i = 0; i < 512; i++) melnotes[i] = new Array();
		var mcount = 0;
		cursor.rewind(0); // beginning of score
		while (cursor.segment) {
			if (cursor.element && cursor.element.type === Element.CHORD) {
				var notes = cursor.element.notes;
				var name;
				// collect top note only
				var i = notes.length - 1;
				//console.log("topnote = ", tpc2note[notes[i].tpc])
				//console.log("pitch = ", notes[i].pitch;
				//console.log("tick = ", cursor.segment.tick)
				melnotes[mcount][0] = tpc2note[notes[i].tpc + 1][1];
				melnotes[mcount][1] = notes[i].pitch;
				melnotes[mcount][2] = cursor.segment.tick;
				mcount++;
			} // end if CHORD 
			else if (cursor.element && cursor.element.type === Element.REST) {
				melnotes[mcount][0] = "rest";
				melnotes[mcount][1] = "rest";
				melnotes[mcount][2] = cursor.segment.tick;
				mcount++;
			}
			cursor.next();
		} // end while segment
		for (var c = 0; c < mcount; c++) {
			//console.log(melnotes[c][0] + " " + melnotes[c][1] + " " + melnotes[c][2])
		}
		cursor.rewind(0); // beginning of score    
		// 1440 voor 3/4
		// 1920 voor 4/4
		var onemeasure = 1920;
		// collect the existing chord symbols and their segment.tick
		var chordnames = new Array(512);
		// chordnames
		// O: chordname
		// 1: tick
		for (var i = 0; i < 512; i++) chordnames[i] = new Array();
		var count = 0;
		for (var track = 0; track <  1; ++track) {
			var segment = curScore.firstSegment();
			while (segment) {
				var aCount = 0;
				var annotation = segment.annotations[aCount];
				while (annotation) {
					if (annotation.type == Element.HARMONY) {
						var harmony = annotation;
						var str = harmony.text;
						if (str != ""){
							//console.log("chord = ", str + " " + segment.tick)
							chordnames[count][0] = str;
							chordnames[count][1] = segment.tick;
						}
						count++;
					}
					annotation = segment.annotations[++aCount];
				}
				segment = segment.next;
			}
		}
        // add a dummy chord at the end
        chordnames[count][0] = str;
		chordnames[count][1] = chordnames[count-1][1] + 1920;
        count++;

		cursor.rewind(0); // beginning of score 
		var thischord = "";
		var oldchord = "";
		
        // loop over the melnotes
		for (var c = 0; c < mcount; c++) {
			var tick = melnotes[c][2];
			// is there a chord at this tick
			thischord = findchord(chordnames, count, tick)
			//console.log("melnote = ", melnotes[c][0] + " " + melnotes[c][2])
			//console.log("chord = ", thischord)
			
			if (melnotes[c][0] != "rest") {
				var thisnote = melnotes[c][0];
				
				var trow = bestVoicing(thisnote, thischord, chords, tpc2note)
				
				if (trow != -1) {
					add1drop2(melnotes, c, chords, trow, cursor)
				} else {
					//console.log("dim thisnote = ", thisnote + " " + thischord + " " + tick)
					var dimchord = thisnote + "dim"
					trow = findDimChord(dimchord, chords);
					add1drop2(melnotes, c, chords, trow, cursor)
				}
			}
		}
		Qt.quit();
	} // end on Run	
}